<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<!-- constants valid for all report types -->
<xsl:variable name="g_is_stats_only" select="/comparison-export/@statistics='yes'" />
<xsl:variable name="g_gui_type" select="/comparison-export/metadata/@gui-type" />
<xsl:variable name="g_is_3way_comparison" select="contains($g_gui_type, '3')" />
<xsl:variable name="g_sources_count">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">3</xsl:when>
	<xsl:otherwise>2</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="g_image_options_node" select="/comparison-export/options/document_types/item[@key='images']/value" />
<xsl:variable name="g_reports_options_node" select="/comparison-export/options/reports_options" />
<xsl:variable name="g_display_options_node" select="/comparison-export/options/display_options" />
<xsl:variable name="g_text_comparison_options_node" select="/comparison-export/options/file_comparison_options | /comparison-export/options/document_types/item[@key='texts']/value/comparison" />
<xsl:variable name="g_folder_comparison_options_node" select="/comparison-export/options/folder_comparison_options | /comparison-export/options/document_types/item[@key='folders']/value/comparison" />
<xsl:variable name="g_folder_display_options_node" select="/comparison-export/options/folder_display_options | /comparison-export/options/document_types/item[@key='folders']/value/display" />
<xsl:variable name="g_folders_reports_options_node" select="$g_reports_options_node/folders_options | /comparison-export/options/document_types/item[@key='folders']/value/reports" />
<xsl:variable name="g_text_reports_options_node" select="$g_reports_options_node/text_files_options | /comparison-export/options/document_types/item[@key='texts']/value/reports" />
<xsl:variable name="g_binary_options_node" select="/comparison-export/options/document_types/item[@key='binaries']/value" />

<xsl:variable name="g_top_level_comparison_type" select="/comparison-export/@object-type" />
<xsl:variable name="g_use_external_css" select="$g_reports_options_node/@css='2'" />
<xsl:variable name="g_use_coloured_css" select="$g_reports_options_node/@css='0'" />
<xsl:variable name="g_use_monochrome_css" select="$g_reports_options_node/@css='1'" />
<xsl:variable name="g_show_line_numbers" select="$g_display_options_node/@show_line_numbers='yes'" />
<xsl:variable name="g_show_skipped_lines" select="$g_text_reports_options_node/@show_skipped_lines='yes'" />
<xsl:variable name="g_can_ignore" select="boolean($g_display_options_node/@ignored_change_text_bgcolor)" />
<xsl:variable name="g_has_sub_reports" select="$g_top_level_comparison_type='folder' and boolean(/comparison-export/sub-reports)" />

<xsl:variable name="g_unchanged_text_fgcolor">
	<xsl:choose>
		<xsl:when test="$g_display_options_node/@unchanged_text_fgcolor">
			<xsl:value-of select="$g_display_options_node/@unchanged_text_fgcolor" />		
		</xsl:when>
		<xsl:otherwise>#000000</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="kg_linefeed"><xsl:text>&#10;</xsl:text></xsl:variable>

<xsl:decimal-format name="default" decimal-separator='.' grouping-separator='&#160;' />

<xsl:template name="metadata-title">

	<xsl:choose>
	<xsl:when test="../@object-type='folder'">
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_compared_folders_titles" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="../@object-type='image-file'">
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_compared_images_titles" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_compared_files_titles" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="metadata_source">
<xsl:param name="node" />
<xsl:param name="position" />

	<xsl:choose>
	<xsl:when test="../@object-type='folder'">
		<xsl:call-template name="metadata-folder-item">
			<xsl:with-param name="position" select="$position" />
			<xsl:with-param name="node" select="$node" />
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="../@object-type='image-file'">
		<xsl:call-template name="metadata-image-item">
			<xsl:with-param name="position" select="$position" />
			<xsl:with-param name="node" select="$node" />
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="../@object-type='binary-file' or ../@object-type='eqtest-file'">
		<xsl:call-template name="metadata-binary-item">
			<xsl:with-param name="position" select="$position" />
			<xsl:with-param name="node" select="$node" />
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="../@object-type='text-file'">
		<xsl:call-template name="metadata-text-item">
			<xsl:with-param name="position" select="$position" />
			<xsl:with-param name="node" select="$node" />
		</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="metadata_bottom">

	<xsl:choose>
	<xsl:when test="../@object-type='folder'">
		<xsl:call-template name="metadata_bottom_folders" />
	</xsl:when>
	<xsl:when test="../@object-type='binary-file' or ../@object-type='eqtest-file'">
		<xsl:call-template name="metadata_bottom_binary_files" />
	</xsl:when>
	<xsl:when test="../@object-type='text-file'">
		<xsl:call-template name="metadata_bottom_text" />
	</xsl:when>
	<xsl:when test="../@object-type='image-file'">
		<xsl:call-template name="metadata_bottom_images" />
	</xsl:when>
	<xsl:otherwise>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="output-yes-no">
<xsl:param name="text"/>

	<xsl:choose>
	<xsl:when test="$text='yes'"><xsl:value-of select="$kg_yes" /></xsl:when>
	<xsl:otherwise><xsl:value-of select="$kg_no" /></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- match tag to output nothing -->
<xsl:template match="languages_options" />

<xsl:template match="statistics">

	<xsl:choose>
	<xsl:when test="../@object-type='binary-file'">
		<xsl:apply-templates select="." mode="binary-files" />
	</xsl:when>
  <xsl:when test="../@object-type='eqtest-file'">
    <xsl:apply-templates select="." mode="eqtest-files" />
  </xsl:when>
  <xsl:when test="../@object-type='image-file'">
		<xsl:apply-templates select="." mode="images" />
	</xsl:when>
	<xsl:when test="../@object-type='text-file'">
		<xsl:apply-templates select="." mode="text-files" />
	</xsl:when>
	<xsl:when test="../@object-type='folder'">
		<xsl:apply-templates select="." mode="folders" />
	</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="statistics_conflicts">

	<xsl:choose>
	<xsl:when test="../@object-type='folder'">
		<xsl:call-template name="statistics_conflicts_details_text" />
	</xsl:when>
	<xsl:when test="../@object-type='text-file'">
		<xsl:call-template name="statistics_conflicts_details_text" />
	</xsl:when>
	<xsl:otherwise>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="attribute_by_name">
<xsl:param name="node" />
<xsl:param name="name" />

	<xsl:call-template name="formatted-number">
		<xsl:with-param name="text">
			<xsl:value-of select="$node/@*[name() = $name]" />
		</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="details-common">
	<xsl:choose>
	<xsl:when test="../@object-type='folder'">
		<xsl:apply-templates select="." mode="folders" />
	</xsl:when>
	<xsl:when test="../@object-type='image-file'">
		<xsl:apply-templates select="." mode="images" />
	</xsl:when>
	<xsl:when test="../@object-type='text-file'">
		<xsl:apply-templates select="." mode="text-files" />
	</xsl:when>
	<xsl:otherwise>
		<!-- nothing to do for binary files -->
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
<xsl:template match="sub-reports">

	<xsl:for-each select="sub-report/comparison-export">
		<hr />
		<xsl:apply-templates select="." />
	</xsl:for-each>
	<hr />
</xsl:template>
-->

<xsl:template name="legend">

	<xsl:choose>
	<xsl:when test="$g_top_level_comparison_type='text-file'">
		<xsl:if test="$g_text_reports_options_node/@details='yes'">
			<xsl:call-template name="output-legend" />
		</xsl:if>
	</xsl:when>
	<xsl:when test="$g_top_level_comparison_type='folder'">
		<xsl:if test="$g_folders_reports_options_node/@details='yes'">
			<xsl:call-template name="output-legend" />
		</xsl:if>
	</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="output-legend-title">

	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_legend_title" />
		</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="output-class-code-common">
<xsl:param name="class" />

	<xsl:choose>
	<xsl:when test="$class='UU'">
		<xsl:value-of select="$kg_unchanged_code" />
	</xsl:when>
	<xsl:when test="$class='CU' or $class='CC' or $class='CI' or $class='CR'">
		<xsl:value-of select="$kg_changed_code" />
	</xsl:when>
	<xsl:when test="$class='AU'">
		<xsl:value-of select="$kg_inserted_code" />
	</xsl:when>
	<xsl:when test="$class='RU' or $class='RR'">
		<xsl:value-of select="$kg_deleted_code" />
	</xsl:when>
	<xsl:when test="$class='IU' or $class='II' or $class='IR'">
		<xsl:value-of select="$kg_ignored_code" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:text>UNKNOWN CLASS</xsl:text>
		<xsl:value-of select="$class" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display-size">
<xsl:param name="size" />

	<xsl:choose>
	<xsl:when test="$size &gt; 1024*1024">
		<xsl:variable name="kb_size" select="number($size div '1024') div '1024'" />

		<xsl:value-of select="number(floor(number($kb_size * '10')) div '10')" />
		<xsl:text> </xsl:text><xsl:value-of select="$kg_mega_bytes" />
	</xsl:when>
	<xsl:when test="$size &gt; 1024">
		<xsl:variable name="kb_size" select="number($size div '1024')" />

		<xsl:value-of select="number(floor(number($kb_size * '10')) div '10')" />
		<xsl:text> </xsl:text><xsl:value-of select="$kg_kilo_bytes" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$size" />
		<xsl:text> </xsl:text><xsl:value-of select="$kg_bytes" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="output-granularity-type">
<xsl:param name="text" />

	<xsl:choose>
	<xsl:when test="$text='files'"><xsl:value-of select="$kg_files" /></xsl:when>
	<xsl:when test="$text='files-text'"><xsl:value-of select="$kg_text_files" /></xsl:when>
	<xsl:when test="$text='files-image'"><xsl:value-of select="$kg_image_files" /></xsl:when>
	<xsl:when test="$text='files-binary'"><xsl:value-of select="$kg_binary_files" /></xsl:when>
	<xsl:when test="$text='blocks'"><xsl:value-of select="$kg_blocks" /></xsl:when>
	<xsl:when test="$text='lines'"><xsl:value-of select="$kg_lines" /></xsl:when>
	<xsl:when test="$text='image-dimensions'"><xsl:value-of select="$kg_image_dimensions" /></xsl:when>
	<xsl:when test="$text='pixels'"><xsl:value-of select="$kg_pixels" /></xsl:when>
  <xsl:when test="$text='bytes'"><xsl:value-of select="$kg_bytes" /></xsl:when>
  <xsl:when test="$text='byteblocks'"><xsl:value-of select="$kg_byteblocks" /></xsl:when>
  <xsl:otherwise>UNKNOWN TYPE OF GRANULARITY <xsl:value-of select="$text" /></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="styles" />

<xsl:variable name="exclude_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@exclude_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@exclude_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:template match="metadata/*/url">

	<xsl:value-of select="@url" />
</xsl:template>

<xsl:template name="source_role">
<xsl:param name="source_idx" />

	<xsl:choose>
	<xsl:when test="$source_idx=0">
		<xsl:value-of select="$kg_ancestor" />
	</xsl:when>
	<xsl:when test="$source_idx=1">
		<xsl:value-of select="$kg_left" />
	</xsl:when>
	<xsl:when test="$source_idx=2">
		<xsl:value-of select="$kg_right" />
	</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="formatted-number">
<xsl:param name="text" />

    <xsl:choose>
        <xsl:when test="$text='0'"> <!-- number 0 is formatted differently by xsltproc and msxml (msxml drops it!) -->
            <xsl:text>0</xsl:text>
        </xsl:when>
        <xsl:when test="$text != ''">
		    <xsl:value-of select="format-number($text, '#&#160;###', 'default')"/>
	    </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template name="string-lower">
<xsl:param name="text" />

	<xsl:value-of select="translate($text,'ABCDEFGIJKLMNOPQRSTUVWXYZ','abcdefgijklmnopqrstuvwxyz')" />
</xsl:template>

<xsl:template name="string-upper">
<xsl:param name="text" />

	<xsl:value-of select="translate($text,'abcdefgijklmnopqrstuvwxyz','ABCDEFGIJKLMNOPQRSTUVWXYZ')" />
</xsl:template>

</xsl:stylesheet>
