﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:template match="details" mode="folders">

	<xsl:if test="$kg_show_heading='yes'">
		<xsl:call-template name="heading-folders" />
	</xsl:if>
	<xsl:apply-templates mode="folders" />
</xsl:template>

<xsl:template match="item[parent::details or parent::item]" mode="folders">

	<xsl:if test="count(*[@deleted='yes'])!=$g_sources_count">
		<!-- conflict level -->
		<xsl:value-of select="$kg_delimiter" />
		<xsl:call-template name="escape-CSV">
			<xsl:with-param name="string" select="@conflict" />
		</xsl:call-template>
		<xsl:value-of select="$kg_delimiter" />

		<xsl:value-of select="$kg_separator" />

		<!-- result -->
		<xsl:value-of select="$kg_delimiter" />
		<xsl:call-template name="escape-CSV">
			<xsl:with-param name="string" select="@result" />
		</xsl:call-template>
		<xsl:value-of select="$kg_delimiter" />

		<xsl:value-of select="$kg_separator" />

		<!-- actions -->
		<xsl:value-of select="$kg_delimiter" />
		<xsl:call-template name="escape-CSV">
			<xsl:with-param name="string" select="@actions" />
		</xsl:call-template>
		<xsl:value-of select="$kg_delimiter" />

		<xsl:value-of select="$kg_separator" />

		<!-- item level -->
		<xsl:value-of select="@level" />

		<xsl:value-of select="$kg_separator" />

		<xsl:apply-templates select="left" mode="folders" />
		<xsl:value-of select="$kg_separator" />
		
		<xsl:if test="$g_is_3way_comparison">
			<xsl:choose>
			<xsl:when test="boolean(ancestor)">
				<xsl:apply-templates select="ancestor" mode="folders" />
				<xsl:value-of select="$kg_separator" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="missing-folder-item-source">
					<xsl:with-param name="node_name">ancestor</xsl:with-param>
				</xsl:call-template>
				<xsl:value-of select="$kg_separator" />
			</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		
		<xsl:apply-templates select="right" mode="folders" />

<xsl:text>
</xsl:text>
		<xsl:apply-templates select="item" mode="folders" />
	</xsl:if>
</xsl:template>

<!-- finds the path relative to a side root -->
<xsl:template name="compute_folder_item_relative_path">
  <xsl:param name="item-side" />

  <xsl:choose>
    <xsl:when test="$item-side[@deleted='yes']">
      <!-- empty string -->
    </xsl:when>
    <xsl:when test="$item-side/parent::node()[@level='0']">
      <xsl:text>.</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="compute_folder_item_relative_path">
        <xsl:with-param name="item-side" select="$item-side/../../*[name()=name($item-side)]" />
      </xsl:call-template>
      <xsl:text>/</xsl:text>
      <xsl:value-of select="$item-side/@filename"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
  
<xsl:template match="item/*[name()!='item']" mode="folders">

	<!-- path -->
  <xsl:variable name="relative_path">
    <xsl:call-template name="compute_folder_item_relative_path">
      <xsl:with-param name="item-side" select="." />
    </xsl:call-template>
  </xsl:variable>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:call-template name="escape-CSV">
		<xsl:with-param name="string" select="$relative_path" />
	</xsl:call-template>
	<xsl:value-of select="$kg_delimiter" />

	<xsl:value-of select="$kg_separator" />
	
	<!-- status -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:call-template name="escape-CSV">
		<xsl:with-param name="string" select="@status" />
	</xsl:call-template>
	<xsl:value-of select="$kg_delimiter" />

	<xsl:value-of select="$kg_separator" />

	<!-- file/folder flag -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:call-template name="escape-CSV">
		<xsl:with-param name="string" select="@is-folder" />
	</xsl:call-template>
	<xsl:value-of select="$kg_delimiter" />

	<xsl:value-of select="$kg_separator" />

	<!-- last modified date -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:if test="@is-folder='no'">
		<xsl:call-template name="escape-CSV">
			<xsl:with-param name="string" select="@modification-date" />
		</xsl:call-template>
	</xsl:if>
	<xsl:value-of select="$kg_delimiter" />

	<xsl:value-of select="$kg_separator" />

	<!-- size -->
	<xsl:if test="@is-folder='no'">
		<xsl:value-of select="@size" />
	</xsl:if>

	<xsl:value-of select="$kg_separator" />

	<!-- diff count -->
	<xsl:value-of select="@diff-count" />

</xsl:template>

<xsl:template name="missing-folder-item-source">
<xsl:param name="node_name" />

	<!-- path -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_delimiter" />

  <!-- status -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>missing !!!</xsl:text>
	<xsl:value-of select="$kg_delimiter" />

  <!-- file/folder flag -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_delimiter" />

  <!-- last modified date -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_delimiter" />

  <!-- size -->
	<xsl:text>&#160;</xsl:text>

  <!-- diff count -->
	<xsl:text>&#160;</xsl:text>
</xsl:template>

<xsl:template name="heading-folders">

	<!-- global item data -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Conflict level</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Result</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Actions</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Item level</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<!-- left item -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left path</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left status</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left item file/folder flag</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left item last modified date</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left item size</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Left item changes count</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<!-- ancestor item -->
	<xsl:if test="$g_is_3way_comparison">
    <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor path</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />

	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor status</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />

	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor item file/folder flag</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />

	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor item last modified date</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />
    
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor item size</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />

	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:text>Ancestor item changes count</xsl:text>
	  <xsl:value-of select="$kg_delimiter" />
	  <xsl:value-of select="$kg_separator" />
  </xsl:if>

	<!-- rigth item -->
	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right path</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right status</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right item file/folder flag</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right item last modified date</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right item size</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
	<xsl:value-of select="$kg_separator" />

	<xsl:value-of select="$kg_delimiter" />
	<xsl:text>Right item changes count</xsl:text>
	<xsl:value-of select="$kg_delimiter" />
  
<xsl:text>
</xsl:text>
</xsl:template>

</xsl:stylesheet>
