// (c) 2008 Elli Computing
// Name: folder-contextual-menu.js
// Version: 1.2
// Purpose: contextual menu items for folders


// NB: we want a few dynamic items so we must make a mix of the '_facilities' infrastructure and some special infrastructure

if (FolderDocument.View !== undefined)
FolderDocument.View.prototype.query_contextual_menu = function () {

	// we need to study the selection, if there is more than one item 
    var own_items = [ ];
	var base_name, base_ext, folder, got_one = false;
	
	function escape (str)
	{
		return str.replace (/''""\\/g, "\\$&");	// NB: doubled the simple quote so that gettext extraction tool does not complain, does not change anythign to the matched set of the regexp so OK
	}
	
	function add_filter (list_name, what)
	{
		var doc = current_frame.coordinator.document;
		var params = doc.parameters.clone();;
		
		params.settings["typed.folders.comparison.filters_options.names_filters."+list_name] += ';' + what;
				
		doc.parameters = params;		
	}
	
	function remove_filter (list_name, what)
	{
		var doc = current_frame.coordinator.document;
		var params = doc.parameters.clone();
		
		var option = params.settings["typed.folders.comparison.filters_options.names_filters."+list_name];
		var options = option.split (";");
		var found = false;
		for (var i=0; i<options.length;)
		{
			if (options[i] == what)
			{
				found = true;
				options.splice (i, 1);
			}
			else
				++i;
		}	
		if (!found)
			log ("pattern " + what + " was not in " + list_name);
			
		params.settings["typed.folders.comparison.filters_options.names_filters."+list_name] = options.join(";");
						
		doc.parameters = params;
	}
	
	function compute_base_name_and_ext(item)
	{
		var parts = /^(\.?.*)\.([^.]+)$/.exec (item.name);
		if (parts)
		{
			base_name = parts[1];
			base_ext = parts[2];
		}
		else
			base_name = item.name;
			
		folder = item.any_folder;
		
		got_one = true;
				
		return false;
	}
	
	
	var sel = current_frame.coordinator.current_view.clone_selection();
	sel.for_each (compute_base_name_and_ext);
		
	if (got_one)
	{
		var item_title = folder ? _("folders") : _("files");
		var actions = [
			{ label: _("Ignore #0 like #1").replace("#0",item_title), event: "1,function () { add_filter ('exclude_list', %0) }" },
			{ label: _("Un-ignore #0 like #1").replace("#0",item_title), event: "1,function () { remove_filter ('exclude_list', %0) }" },
			{ label: _("Include only #0 like #1").replace("#0",item_title), event: "1,function () { add_filter ('include_list', %0) }" },
			{ label: _("Un-include only #0 like #1").replace("#0",item_title), event: "1,function () { remove_filter ('include_list', %0) }" }	];
		
		function add_masked_actions (menu, actions, mask)
		{
			for (var i=0; i<actions.length; ++i)
			{
				var action = actions[i];
				menu.push ( { label: action.label.replace("#1", mask), event: eval (action.event.replace('%0', "'"+escape(mask)+"'")) } );
			}			
		}
		
		if (base_name)
			add_masked_actions (own_items, actions, base_name + (folder ? "/" : ".*"));
		
		if (base_ext)
			add_masked_actions (own_items, actions, "*." + base_ext + (folder ? "/" : ""));

		own_items.push ( { label: "" } ); // add a separator
	}
	
	function set_specified_dates_for_selected_files (access, modification, creation) {
		function do_it(i) {
			VFS.set_dates (i.get_url (current_frame.coordinator.current_view.role),
				access, modification, creation);
		}
	
		sel.for_each (do_it);
	}	
	
	function touch_selected_files () {
		set_specified_dates_for_selected_files (undefined, new Date(), undefined);
	}
	
	function set_dates_for_selected_files () {

		var dates_str = ec_prompt_with_choices (_("Please enter files dates to set for all files as 'modification[|creation[|access]]':\n(using a format such as YYYY/MM/DD HH:MM:SS[.mmmm])"),
			"folder_ctxt_menu_dates_to_set");
		if (dates_str)
		{
			var dates_strs = dates_str.split("|");
			var dates = [];
			for (var i in dates_strs)
				dates[i] = new Date(Date.parse (dates_strs));
						
			set_specified_dates_for_selected_files (dates[2], dates[0], dates[1]);
		}
	}
	
	own_items.push ( { label: _("Touch"), event: touch_selected_files } );
	own_items.push ( { label: _("Set dates"), event: set_dates_for_selected_files } );
	

	// let get the base items as well.
    if (this.__proto__.__proto__.query_contextual_menu !== undefined)
    {
        try {
            var proto_items = this.__proto__.__proto__.query_contextual_menu.call (this);
        }
        catch (e) {
            log ("there was a problem in Document.View.prototype.query_contextual_menu\n"+ String(e) );
        }
        if (proto_items !== undefined && proto_items.length != 0)
        {
			if (own_items.length!=0)
			{
				proto_items.splice (0, 0, 0, 0);
				proto_items.push ( [ { label: '' } ] );
				own_items.splice.apply (own_items, proto_items);
			}
			else
				own_items = proto_items;
        }
    }
    return own_items;
}

// no need for static stuff
//ec_check_array_script_generation ("contextual_menu_items", FolderDocument.View.prototype);
//FolderDocument.View.prototype.contextual_menu_items.push ( { label: "menu item", event:function() { alert("hi hoo") } } );
