// (c) Elli Computing
// Name: folders-easy-sync.js
// Version: 1.1
// Purpose: proposes a popup-menu with various simple synchronization functions

macros["folders_easy_sync"] = function() {
	
	function synchronize (source, target) {
	
		function is_selection_empty(sel) {
			var at_least_one = false;
			
			sel.for_each (function() { at_least_one=true; return false; });
			return !at_least_one;
		}
	
		// the idea here is to simply run the resolve command 
		
		if (/diff./.test(current_doc.parameters.gui_type))
		{
			// make the folder a merge view (then re-select)
			var params = current_doc.parameters.clone();
			params.gui_type = current_doc.parameters.gui_type.replace('diff', 'merge');
			current_doc.parameters = params;
	
// saves and reloads a selection, finally not used but still interesting to keep
//			// selection does not survive document reload... serialize it to an array
//			var selection_array=[];
//			selection.for_each(function(i) { selection_array.push(i.get_url(source)); return true; });
//			selection.remove(current_doc.root);
//			
//			for (i in selection_array)
//				selection.add (current_doc.get_item(selection_array[i], source));
//			current_frame.coordinator.current_view.set_selection (selection);
		}
		
		var params = current_doc.parameters.clone();
		params.left.output = true;
		params.right.output = true;
		params.ancestor.output = false;
		params.result.output = false;
		current_doc.parameters = params;
		
		var selection = new FolderDocument.Selection (current_doc, true);
		
		current_doc.resolve (selection, new FolderDocument.MergeRulesSet("mimic:"+source), true);

		if (ec_check_version ("2.2.101"))
		{
			if (confirm (_("Mirroring was setup for selected items. Do you want to act immediately?\n") +
					_("If not, you can review first the actions in the result panel")))
				current_doc.merge (selection);
		}
		else
		{
			alert(_("Now please review the changes in the Result bottom panel, \nthen click the 'Write merge results' button to finalize your work or see the exact list of operations with the Test button\nYou can change item per item which side to keep using the Resolve with Left/Right toolbar buttons"));
		}
	}
	
	function bidi_consolidation()
	{
		if (/diff./.test(current_doc.parameters.gui_type))
		{
			// make the folder a merge view (then re-select)
			var params = current_doc.parameters.clone();
			params.gui_type = current_doc.parameters.gui_type.replace('diff', 'merge');
			current_doc.parameters = params;
		}
	
		var params = current_doc.parameters.clone();
		params.left.output = true;
		params.right.output = true;
		params.ancestor.output = false;
		params.result.output = false;
		current_doc.parameters = params;
		
		var selection = new FolderDocument.Selection (current_doc, true);
		
		var mrs = new FolderDocument.MergeRulesSet;
		mrs["source-only"] = "keep";
		mrs["target-only"] = "keep";
		mrs["diff-merge-able"] = "most-recent";
		mrs["diff-non-merge-able"] = "most-recent";
		
		current_doc.resolve (selection, mrs, true);
	}
	
	function setup_fast_comparison ()
	{
		var params = current_doc.parameters.clone();
		params.settings["typed.folders.comparison.different_date_mean_different_files"] = true;
		params.settings["typed.folders.comparison.different_size_mean_different_files"] = true;
		params.settings["typed.folders.comparison.equal_date_and_size_mean_equal_files"] = true;
		params.settings["typed.folders.comparison.equal_date_mean_equal_files"] = false;
		params.settings["typed.folders.comparison.equal_size_mean_equal_files"] = false;
		current_doc.parameters = params;
	}

	function setup_full_comparison ()
	{
		var params = current_doc.parameters.clone();
		params.settings["typed.folders.comparison.different_date_mean_different_files"] = false;
		params.settings["typed.folders.comparison.different_size_mean_different_files"] = false;
		params.settings["typed.folders.comparison.equal_date_and_size_mean_equal_files"] = true;
		params.settings["typed.folders.comparison.equal_date_mean_equal_files"] = false;
		params.settings["typed.folders.comparison.equal_size_mean_equal_files"] = false;
		current_doc.parameters = params;
		
		if (!(current_doc.information && current_doc.information.background_content_diff))
			execute_macro("options_toggle_background_content_diff")
	}
	
	var current_doc = current_frame.coordinator.document;
	if (! (current_doc instanceof FolderDocument) ||
		! /(diff|merge)./.test(current_doc.parameters.gui_type))
		return log("Not a folder comparision document");
		
	var menu = [ 
		{ label:_("Synchronize left to right"), event: function() { synchronize('left','right') } },
		{ label:_("Synchronize right to left"), event: function() { synchronize('right','left') } },
		{ label:_("Bidirectional consolidation"), event: function() { bidi_consolidation(); } },
		{ label: '' },
		{ label:_("Turn options for fast comparison"), event: setup_fast_comparison },
		{ label:_("Turn options for thorough comparison"), event: setup_full_comparison },
		{ label:_("Compare all sub-folders"), type:"check", checked: current_doc.information && current_doc.information.visiting_sub_folders, event: function() { execute_macro("options_toggle_folder_visit") } },
		{ label:_("Compare files content when metadata are not enough"), type:"check", checked: current_doc.information && current_doc.information.background_content_diff, event: function() { execute_macro("options_toggle_background_content_diff") } },
	];
	
	popup_menu (menu);
}
macros["folders_easy_sync"].label = _("Easy synchronization");
macros["folders_easy_sync"].toolbar_name = "folders"; 
macros["folders_easy_sync"].icon_url = script_url.compose("../folders-easy-sync.png"); 
macros["folders_easy_sync"].available_for_document_types = "folders";
