// (c) Elli Computing
// Name: inline-up-down.js
// Version: 1.2
// Purpose: let the user browse differences with in-line precision
// History:
//	1.1 binary search moved to '_facilities.js'

// collection: the collection of differences
// role: left/right/ancestor side in which search happens
// side: 0 or 1 (0 for first role of comparison, 1 for second, as in : left-right, ancestor-left...)
// position: position in characters in the searched side
// search_direction: 1 to search toward larger positions (down), -1 for the smaller positions (up)
// returns a LinearRange pair (a Array of length 2) representing the found difference, 
//	or if not found (0,0) when going up, and (max,max) when going down and in this case 
//	the member 'ok' is not defined
function ec_find_inline_diff (doc, role, other_role, collection, side, position, search_direction)
{
	var line_position = doc.content[role].line_from_position(position);
	var side_srctgt = side==0 ? "source" : "target";
	var srcrole = side==0 ? role : other_role;
	var tgtrole = side==1 ? role : other_role;
		
	function lines_comp (line_diff, line_pos)
	{
		var r = line_diff.lines(side_srctgt);
		if (r.start > line_pos) return 1;
		if (r.end < line_pos) return -1; // include end else cannot jump deleted portions
		return 0;
	}
	function inlines_comp (inline_diff, pos)
	{
		var r = inline_diff.characters(side_srctgt);
		if (r.start > pos) return 1;
		if (r.end < pos) return -1; // include end else cannot jump deleted portions
		return 0;
	}

	// find the difference we may be in (if there is find
	//	a potential the inline difference there), if there is no such diff, go
	//	to the next diff (if it has inline diff go to it, else just go to the
	//	line diff)
	var inline_diffs;
	var line_diff_search = ec_binary_search (collection, lines_comp, line_position);
	var inline_diff_search;
	if (line_diff_search.found)
	{
		// we found a line difference containing the line we lie in, try to find
		//	and inline-diff.
		inline_diffs = collection[line_diff_search.found_at].inline_differences;
		inline_diff_search = ec_binary_search (inline_diffs, inlines_comp, position  -
			doc.content[role].position_from_line(collection[line_diff_search.found_at].lines(side_srctgt).start));
			
		if (inline_diff_search.found || search_direction < 0)
			inline_diff_search.found_at += search_direction;
		if (inline_diff_search.found_at >= 0 && inline_diff_search.found_at < inline_diffs.length)
		{
			// log ("found inline diff within current diff");

			var pair = [ inline_diffs[inline_diff_search.found_at].characters("source"),
					     inline_diffs[inline_diff_search.found_at].characters("target") ];
			pair[0].start += doc.content[srcrole].position_from_line(collection[line_diff_search.found_at].lines("source").start);
			pair[1].start += doc.content[tgtrole].position_from_line(collection[line_diff_search.found_at].lines("target").start);
			pair.ok = true;
			return pair;
		}
			
		// the next inline difference is not in the current difference... let's search next
	}

	if (line_diff_search.found || search_direction < 0)
		line_diff_search.found_at += search_direction;
		
	while (line_diff_search.found_at >= 0 && line_diff_search.found_at < collection.length && 
		   collection[line_diff_search.found_at].ignored)
		line_diff_search.found_at += search_direction;
		
	// log ("collection.length:" + collection.length);
	if (line_diff_search.found_at >= 0 && line_diff_search.found_at < collection.length)
	{
		inline_diffs = collection[line_diff_search.found_at].inline_differences;
		inline_diff_search = ec_binary_search (inline_diffs, inlines_comp, position -
			doc.content[role].position_from_line(collection[line_diff_search.found_at].lines(side_srctgt).start));
			
		if (inline_diff_search.found) throw alert("abnormal situation");		
		
		if (search_direction < 0)
			inline_diff_search.found_at += search_direction;
		if (inline_diff_search.found_at >= 0 && inline_diff_search.found_at < inline_diffs.length)
		{
			var pair = [ inline_diffs[inline_diff_search.found_at].characters("source"),
					     inline_diffs[inline_diff_search.found_at].characters("target") ];
			pair[0].start += doc.content[srcrole].position_from_line(collection[line_diff_search.found_at].lines("source").start);
			pair[1].start += doc.content[tgtrole].position_from_line(collection[line_diff_search.found_at].lines("target").start);
			
			pair.ok = true;
			return pair;
		}
		
		// log ("found line diff: " + line_diff_search.found_at);
		
		var lines = [ collection[line_diff_search.found_at].lines("source"), 
						collection[line_diff_search.found_at].lines("target") ];
		var pair = [ new LinearRange(doc.content[srcrole].position_from_line(lines[0].start), 0),
					 new LinearRange(doc.content[tgtrole].position_from_line(lines[1].start), 0) ];
		pair[0].end = doc.content[srcrole].position_from_line(lines[0].end);
		pair[1].end = doc.content[tgtrole].position_from_line(lines[1].end);
		
		pair.ok = true;
		return pair;
	}
	
	// log ("going to limit");
	
	if (search_direction < 0)
		return [new LinearRange (0,0), new LinearRange (0,0)];
	else
		return [new LinearRange (doc.content[srcrole].length, 0), new LinearRange (doc.content[tgtrole].length, 0)];
}

// search_direction: -1 up, 1 down
// skip_re: if defined: if both sides match the RE continue until top or down is reached
function ec_move_inline_diff (search_direction, skip_re, skip_empty)
{
	var currentdoc = current_frame.coordinator.document;
	if (!(currentdoc instanceof TextDocument) ||
		!currentdoc.parameters.gui_type.match(/(diff|merge)(2|3)/))
		return execute_macro(search_direction<0 ? "goto_prev_diff" : "goto_next_diff" );
		
	// find from where we go
	var side = current_frame.coordinator.current_view.role;
	
	// find which collection(s) to search
	var to_search = [];
	if (currentdoc.parameters.gui_type.match(/.*3/))
	{
		if (side == 'ancestor')
		{
			// log("searching in ancestor");
			to_search.push ( { collection: currentdoc.differences("ancestor-left"), side: 0, sides: ["ancestor", "left"] } );
			to_search.push ( { collection: currentdoc.differences("ancestor-right"), side: 0, sides: ["ancestor", "right"] } );
		}
		else
		{
			// log("searching in 3-way, " + side + " side");
			to_search.push ( { collection: currentdoc.differences("ancestor-"+side), side: 1, sides: ["ancestor", side] } );
		}
	}
	else
	{
		// log("searching in 2-way, " + side + " side");
		to_search.push ( { collection: currentdoc.differences("left-right"), side: (side=='left' ? 0 : 1), sides: ["left", "right"] } );
	}
	
	var selection = current_frame.coordinator.current_view.clone_selection();
	var range_extremity = search_direction<0 ? "start" : "end";
	var position = selection.range[range_extremity];
	
	while (true)
	{
		var results = [];
		for (var i=0; i<to_search.length; ++i)
		{
			results.push (ec_find_inline_diff(currentdoc, to_search[i].sides[to_search[i].side],
				to_search[i].sides[1 - to_search[i].side],
				to_search[i].collection, to_search[i].side, position, search_direction));
		}
		
		var best_result = 0;
		var result_ranges = results[0];
		if (results.length == 2 &&
			((search_direction<0 && result_ranges[to_search[0].side].end < results[1][to_search[1].side].end) ||
			(search_direction>0 && result_ranges[to_search[0].side].start > results[1][to_search[1].side].start)))
		{
			best_result = 1;
			result_ranges = results[1];
		}
		
		if (skip_re !== undefined && result_ranges.ok !== undefined)
		{
			var can_skip = true;
			for (var i=0; i<result_ranges.length && can_skip; ++i)
			{
				var iside = to_search[best_result].sides[i];
				can_skip = (skip_empty && result_ranges[i].length <=0) ||
								currentdoc.content[iside].get_text(new TextDocument.Selection(currentdoc.content[iside], result_ranges[i])).match(skip_re);
			}
			
			if (can_skip)
			{
				position = result_ranges[0][range_extremity];
				continue; // search again from that position			
			}
		}		
		
		// now select in each view the result ranges (with a minimum length of 1
		//	though, so that it is always a bit visible)
		for (var i=0; i<result_ranges.length; ++i)
		{
			// log ("result_ranges[i] = [" + result_ranges[i].start + ", " + result_ranges[i].end + ")");
			
			if (result_ranges[i].length < 1) result_ranges[i].length = 1;
					
			var iside = to_search[best_result].sides[i];
			var iview = current_frame.coordinator.views[iside];
			iview.navigate (result_ranges[i][range_extremity]);
			iview.set_selection(new TextDocument.Selection(currentdoc.content[iside], result_ranges[i]));
		}
		
		break; // its finished
	}
}

macros["ec_inline_up"] = function() {
	ec_move_inline_diff (-1);
}
macros["ec_inline_up"].label = _("Previous Difference Inside Line");
macros["ec_inline_up"].toolbar_name = "Text";
macros["ec_inline_up"].icon_url = script_url.compose ('../inline-prev-16.png');
macros["ec_inline_up"].toolbar_rank = 1;
macros["ec_inline_up"].available_for_document_types = "texts";

macros["ec_inline_down"] = function() {
	ec_move_inline_diff (1);
}
macros["ec_inline_down"].label = _("Next Difference Inside Line");
macros["ec_inline_down"].toolbar_name = "Text";
macros["ec_inline_down"].icon_url = script_url.compose ('../inline-next-16.png');
macros["ec_inline_down"].toolbar_rank = 2;
macros["ec_inline_down"].available_for_document_types = "texts";

macros["ec_inline_up_skip_blanks"] = function() {
	ec_move_inline_diff (-1, /^[ \t\r\n]*$/, true);
}
macros["ec_inline_up_skip_blanks"].label = _("Previous Difference Inside Line") + ", " + _("skip blanks");
macros["ec_inline_up_skip_blanks"].toolbar_name = "Text";
macros["ec_inline_up_skip_blanks"].toolbar_rank = 1.1;
macros["ec_inline_up_skip_blanks"].available_for_document_types = "texts";

macros["ec_inline_down_skip_blanks"] = function() {
	ec_move_inline_diff (1, /^[ \t\r\n]*$/, true);
}
macros["ec_inline_down_skip_blanks"].label = _("Next Difference Inside Line") + ", " + _("skip blanks");
macros["ec_inline_down_skip_blanks"].toolbar_name = "Text";
macros["ec_inline_down_skip_blanks"].toolbar_rank = 2.1;
macros["ec_inline_down_skip_blanks"].available_for_document_types = "texts";
