// (c) Elli Computing
// Name: validate-xml.js
// Version: 1.1
// Purpose: checks that a file is indeed well-formed XML
//	currently this macro runs only on a text document, it could be rather easily extend to verify all
//	the selected files in a folder
//	this macro is based on SAX parser from XML for <SCRIPT> project (http://xmljs.sourceforge.net/)
//	xmlsax.js was left untouched, so you can extract it from the archive downloaded there.
//	the icon comes from Gnome icon collection.
// a copy of LGPL (which covers xmlsax.js) is provided under licences/ directory

macros["validate_xml"] = function() {

	var currentview = current_frame.coordinator.current_view;
	var currentrole = currentview.role;

	var currentdoc = current_frame.coordinator.document;
	if (!(currentdoc instanceof TextDocument))
		return alert(_("works only on a text documents"));
	
	
	validate_xml_text (String(currentdoc.content[currentrole]));
}
macros["validate_xml"].label = _("XML Validation");
macros["validate_xml"].toolbar_name = "xml";
macros["validate_xml"].shortcut = "Ctrl+Shift+Y";
macros["validate_xml"].icon_url = script_url.compose("../validate-xml.png");
macros["validate_xml"].available_for_document_types = "texts";

function validate_xml_text (str)
{
	function LoggerHandler()
	{
		this.hadMessages = false;
	}
	
	function log_at_position(title, line, col, msg)
	{
		log (title + " (line:"+ line + ", col:"+ col +"): " + msg);
	}
	
	function log_exception(title, exception)
	{
		log_at_position (title, exception.getLineNumber(), exception.getColumnNumber(), exception.getMessage());
	}
	
	LoggerHandler.prototype.warning = function (exception)
	{
		log_exception("Warning", exception);
		this.hadMessages = true;
	}
	LoggerHandler.prototype.error = function (exception)
	{
		log_exception("Error", exception);
		this.hadMessages = true;
	}
	LoggerHandler.prototype.fatalError = function (exception)
	{
		log_exception("Fatal Error", exception);
		this.hadMessages = true;
	}
	
	var loggerHandler = new LoggerHandler();
	var stackCheckerHandler = new LoggerHandler();
	var checker = new SAXDriver();
	checker.setErrorHandler(loggerHandler);
	checker.setDocumentHandler(loggerHandler);
	
	checker.parse (str);
	
	if (checker.m_parser.m_stack.count() != 0)
	{
		for (var i=checker.m_parser.m_stack.count()-1; i>=0; --i)
		{
			var tag = checker.m_parser.m_stack.m_arr[i];
			log_at_position ("Error", SAXStrings.getLineNumber(str, tag.ip), SAXStrings.getColumnNumber(str, tag.ip), "tag not closed: " + tag.name);
		}
		loggerHandler.hadMessages = true;
	}
	
	if (!loggerHandler.hadMessages)
		log("No error found");
}

