<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:template name="metadata_bottom_binary_files" />

<xsl:template name="metadata-binary-item">
<xsl:param name="position" />
<xsl:param name="node" />

	<table class="tablebox" cellspacing="1">
		<xsl:if test="$position = 0">
        <xsl:attribute name="align">center</xsl:attribute>
    </xsl:if>
		<tr>
			<td colspan="2" class="tablebox_header hth">
			<xsl:call-template name="source_role">
				<xsl:with-param name="source_idx">
          <xsl:value-of select="$position" />
        </xsl:with-param>
			</xsl:call-template>
			</td>
		</tr>
		<xsl:choose>
		<xsl:when test="boolean($node) and $node/last-metadata/@deleted!='yes'">
			<tr>
				<td colspan="2" class="hth">
					<xsl:choose>
					<xsl:when test="boolean($node/@title) and $node/@title != ''">
						<b><xsl:value-of select="$node/@title" /></b>
					</xsl:when>
					<xsl:otherwise>
						<b><xsl:apply-templates select="$node/url" /></b>
					</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_last_modified" /></td>
				<td>
					<span>
						<xsl:attribute name="title">
							<xsl:value-of select="$node/last-metadata/@modification-date" />
						</xsl:attribute>
						<xsl:value-of select="substring-before($node/last-metadata/@modification-date, '.')" />
					</span>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_size" /></td>
				<td>
					<xsl:call-template name="display-size">
						<xsl:with-param name="size" select="$node/last-metadata/@size" />
					</xsl:call-template>
				</td>
			</tr>
		</xsl:when>
		<xsl:otherwise>
			<tr>
				<td colspan="2">
					<xsl:value-of select="$kg_missing_file" />
				</td>
			</tr>
		</xsl:otherwise>
		</xsl:choose>
	</table>
</xsl:template>

<xsl:template match="statistics" mode="binary-files">

  <!-- title -->
  <xsl:choose>
    <xsl:when test="$g_is_stats_only">
      <h2><xsl:value-of select="$kg_statistics_report_title" /></h2>
    </xsl:when>
    <xsl:otherwise>
      <br /><br />
      <xsl:call-template name="display_heading">
        <xsl:with-param name="text">
          <xsl:value-of select="$kg_statistics_title" />
        </xsl:with-param>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>

  <!-- data table -->
  <xsl:call-template name="detailed_stats_for_binary_files" />

</xsl:template>

<xsl:template name="detailed_stats_for_binary_files">

  <h2>
    <xsl:choose>
      <xsl:when test="../@object-type='binary-file'">
        <xsl:value-of select="$kg_statistics_detailed_one_binary_title" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$kg_statistics_detailed_binary_title" />
      </xsl:otherwise>
    </xsl:choose>
  </h2>
  <p>
    <div style="float:left; padding-right:10px;">
      <xsl:call-template name="statistics_details_binary" />
    </div>
    <xsl:if test="$g_is_3way_comparison">
      <div style="float:left;">
        <!-- conflicts -->
<!--        <xsl:call-template name="statistics_conflicts" />-->
        <xsl:text> </xsl:text>
        <!-- IE bug, clear does not work with empty floating spans -->
      </div>
    </xsl:if>
  </p>
  <br style="clear:both;" />
</xsl:template>

<xsl:template name="statistics_details_binary">

  <xsl:value-of select="$kg_all_changes" />
  <br />
  <table>
    <xsl:choose>
      <xsl:when test="$g_is_stats_only">
        <xsl:attribute name="cellspacing">0</xsl:attribute>
        <xsl:attribute name="cellpadding">3</xsl:attribute>
        <xsl:attribute name="border">1px</xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="class">tablebox</xsl:attribute>
        <xsl:attribute name="cellspacing">1</xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:variable name="node_set" select="all/pair/granularity[@type='byteblocks' or @type='bytes']" />
    <xsl:choose>
      <xsl:when test="$g_is_3way_comparison">
        <xsl:call-template name="statistics_table_header">
          <xsl:with-param name="pair_nodes" select="all/pair" />
          <xsl:with-param name="stats_nodes_count" select="count(all/pair[1]/granularity[@type='byteblocks' or @type='bytes'])" />
          <xsl:with-param name="description_title">
            <xsl:value-of select="$kg_description" />
          </xsl:with-param>
          <xsl:with-param name="description_rowspan">2</xsl:with-param>
        </xsl:call-template>
        <xsl:call-template name="statistics_table_header_data_types">
          <xsl:with-param name="stats_nodes" select="$node_set" />
          <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="statistics_table_header_data_types">
          <xsl:with-param name="empty_left_cell">yes</xsl:with-param>
          <xsl:with-param name="empty_left_cell_colspan">2</xsl:with-param>
          <xsl:with-param name="stats_nodes" select="$node_set" />
          <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:call-template name="statistics_data_line_per_diff_type">
      <xsl:with-param name="nodes" select="$node_set" />
      <xsl:with-param name="attr_name">unchanged</xsl:with-param>
      <xsl:with-param name="rowspan">1</xsl:with-param>
      <xsl:with-param name="colspan">2</xsl:with-param>
      <xsl:with-param name="text1">
        <xsl:value-of select="$kg_unchanged_items" />
      </xsl:with-param>
      <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="statistics_data_line_per_diff_type">
      <xsl:with-param name="nodes" select="$node_set" />
      <xsl:with-param name="attr_name">inserted</xsl:with-param>
      <xsl:with-param name="rowspan">1</xsl:with-param>
      <xsl:with-param name="colspan">2</xsl:with-param>
      <xsl:with-param name="text1">
        <xsl:value-of select="$kg_inserted_items" />
      </xsl:with-param>
      <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="statistics_data_line_per_diff_type">
      <xsl:with-param name="nodes" select="$node_set" />
      <xsl:with-param name="attr_name">deleted</xsl:with-param>
      <xsl:with-param name="rowspan">1</xsl:with-param>
      <xsl:with-param name="colspan">2</xsl:with-param>
      <xsl:with-param name="text1">
        <xsl:value-of select="$kg_deleted_items" />
      </xsl:with-param>
      <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
    </xsl:call-template>
<!--
    <xsl:if test="$g_can_ignore">
      <xsl:call-template name="statistics_data_line_per_diff_type">
        <xsl:with-param name="nodes" select="$node_set" />
        <xsl:with-param name="attr_name">ignored</xsl:with-param>
        <xsl:with-param name="rowspan">1</xsl:with-param>
        <xsl:with-param name="colspan">2</xsl:with-param>
        <xsl:with-param name="text1">
          <xsl:value-of select="$kg_ignored_items" />
        </xsl:with-param>
        <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
      </xsl:call-template>
    </xsl:if>
-->
    <xsl:call-template name="statistics_data_line_per_diff_type">
      <xsl:with-param name="nodes" select="$node_set" />
      <xsl:with-param name="attr_name">changed</xsl:with-param>
      <xsl:with-param name="rowspan">1</xsl:with-param>
      <xsl:with-param name="colspan">2</xsl:with-param>
      <xsl:with-param name="text1">
        <xsl:value-of select="$kg_changed_items" />
      </xsl:with-param>
      <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
    </xsl:call-template>
  </table>
</xsl:template>

</xsl:stylesheet>
