﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:variable name="g_text_details_columns_nb">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:choose>
		<xsl:when test="$g_show_line_numbers">11</xsl:when>
		<xsl:otherwise>8</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:choose>
		<xsl:when test="$g_show_line_numbers">7</xsl:when>
		<xsl:otherwise>5</xsl:otherwise>
		</xsl:choose>
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="g_use_inline_diff">
	<xsl:if test="$g_text_comparison_options_node/@word_level='yes' or $g_text_comparison_options_node/@char_level='yes'">yes</xsl:if>
</xsl:variable>

<xsl:variable name="g_unify_identical_lines" select="$g_text_reports_options_node/@identical_parts_as_single_column" />

<xsl:template name="metadata_bottom_text" />

<xsl:template name="metadata-text-item">
<xsl:param name="position" />
<xsl:param name="node" />

<xsl:variable name="content-info-node" select="$node/../../content-info/*[name() = name($node)]" />

	<table class="tablebox" cellspacing="1">
		<xsl:if test="$position = 0"><xsl:attribute name="align">center</xsl:attribute></xsl:if>
		<tr>
			<td colspan="2" class="tablebox_header hth">
			<xsl:call-template name="source_role">
				<xsl:with-param name="source_idx"><xsl:value-of select="$position" /></xsl:with-param>
			</xsl:call-template>
			</td>
		</tr>
		<xsl:choose>
		<xsl:when test="boolean($node) and $node/last-metadata/@deleted!='yes'">
			<tr>
				<td colspan="2" class="hth">
					<xsl:choose>
					<xsl:when test="boolean($node/@title) and $node/@title != ''">
						<b><xsl:value-of select="$node/@title" /></b>
					</xsl:when>
					<xsl:otherwise>
						<b><xsl:apply-templates select="$node/url" /></b>
					</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_last_modified" /></td>
				<td>
					<span>
						<xsl:attribute name="title">
							<xsl:value-of select="$node/last-metadata/@modification-date" />
						</xsl:attribute>
						<xsl:value-of select="substring-before($node/last-metadata/@modification-date, '.')" />
					</span>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_size" /></td>
				<td>
					<xsl:call-template name="display-size">
						<xsl:with-param name="size" select="$node/last-metadata/@size" />
					</xsl:call-template>
					<xsl:if test="boolean($content-info-node)">
						<xsl:text> (</xsl:text>
						<xsl:call-template name="formatted-number">
							<xsl:with-param name="text">
								<xsl:value-of select="$content-info-node/@lines-count" />
							</xsl:with-param>
						</xsl:call-template>
						<xsl:text> </xsl:text>
						<xsl:value-of select="$kg_lines" />
						<xsl:text>)</xsl:text>
					</xsl:if>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_encoding" /></td>
				<td>
					<xsl:value-of select="$content-info-node/@encoding" />
					<xsl:text> </xsl:text>
					<xsl:choose>
					<xsl:when test="$content-info-node/@encoding-origin='detected'">
						<xsl:value-of select="$kg_encoding_autodetected" />
					</xsl:when>
					<xsl:when test="$content-info-node/@encoding-origin='default'">
						<xsl:value-of select="$kg_encoding_default" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$kg_encoding_forced" />
					</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</xsl:when>
		<xsl:otherwise>
			<tr>
				<td colspan="2">
					<xsl:value-of select="$kg_missing_file" />
				</td>
			</tr>
		</xsl:otherwise>
		</xsl:choose>
	</table>
</xsl:template>

<xsl:template match="details" mode="text-files">

	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_details_title" />
		</xsl:with-param>
	</xsl:call-template>

  <div class="divbox">
	<table class="tablebox details" cellspacing="0" width="100%">
		<colgroup>
			<xsl:choose>
			<xsl:when test="$g_is_3way_comparison">
				<xsl:choose>
				<xsl:when test="$g_show_line_numbers">
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="33%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="34%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="33%"/>			<!-- text content -->
				</xsl:when>
				<xsl:otherwise>
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="33%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="34%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="33%"/>			<!-- text content -->
				</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
				<xsl:when test="$g_show_line_numbers">
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="50%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="50%"/>			<!-- text content -->
				</xsl:when>
				<xsl:otherwise>
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="50%"/>			<!-- text content -->
					<col style="width: 2em;"/>	<!-- text separator -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col width="50%"/>			<!-- text content -->
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
			</xsl:choose>
		</colgroup>
		<xsl:apply-templates mode="text-files" />
	</table>
	</div>
</xsl:template>

<xsl:template match="details/line" mode="text-files">

	<tr>
		<xsl:choose>
		<xsl:when test="boolean(@skipped)">
			<xsl:call-template name="output-skipped-line" />
		</xsl:when>
		<xsl:when test="$g_unify_identical_lines='yes' and not (@conflict-middle) and count(source[@class='UU'])=$g_sources_count">
			<xsl:call-template name="output-unified-line" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="source[@role=1]" mode="text-files">
				<xsl:with-param name="left" select="@conflict-middle" />
			</xsl:apply-templates>
			<td>
				<xsl:attribute name="class">
					<xsl:variable name="attr">
						<xsl:call-template name="conflict-border">
							<xsl:with-param name="top" select="@conflict-start" />
							<xsl:with-param name="bottom" select="@conflict-last" />
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="normalize-space($attr)" />
				</xsl:attribute>
				<xsl:text>&#160;</xsl:text>
			</td>
			<xsl:if test="$g_is_3way_comparison">
				<xsl:apply-templates select="source[@role=0]" mode="text-files" />
				<td>
					<xsl:attribute name="class">
						<xsl:variable name="attr">
							<xsl:call-template name="conflict-border">
								<xsl:with-param name="top" select="@conflict-start" />
								<xsl:with-param name="bottom" select="@conflict-last" />
							</xsl:call-template>
						</xsl:variable>
						<xsl:value-of select="normalize-space($attr)" />
					</xsl:attribute>
					<xsl:text>&#160;</xsl:text>
				</td>
			</xsl:if>
			<xsl:apply-templates select="source[@role=2]" mode="text-files">
				<xsl:with-param name="right" select="@conflict-middle" />
			</xsl:apply-templates>
		</xsl:otherwise>
		</xsl:choose>
	</tr>
</xsl:template>

<xsl:template name="single-cell-line-attrs">
<xsl:param name="skipped" select="''" />

	<xsl:attribute name="colspan"><xsl:value-of select="$g_text_details_columns_nb" /></xsl:attribute>
	<xsl:attribute name="class">
		<xsl:text>single_cell </xsl:text>
		<xsl:variable name="attr">
			<xsl:if test="$skipped">
				<xsl:text>skipped </xsl:text>
			</xsl:if>
			<xsl:call-template name="conflict-border">
				<xsl:with-param name="left" select="@conflict-middle" />
				<xsl:with-param name="right" select="@conflict-middle" />
				<xsl:with-param name="top" select="@conflict-start" />
				<xsl:with-param name="bottom" select="@conflict-last" />
			</xsl:call-template>
		</xsl:variable>
		<xsl:value-of select="normalize-space($attr)" />
	</xsl:attribute>
</xsl:template>

<xsl:template name="output-unified-line"> <!-- used for 'simple equality' lines -->

	<td cellpadding="0" >
	<xsl:call-template name="single-cell-line-attrs" />
	<table border="0" cellspacing="0" cellpadding="0" width="90%">
		<colgroup>
			<xsl:choose>
			<xsl:when test="$g_is_3way_comparison">
				<xsl:choose>
				<xsl:when test="$g_show_line_numbers">
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col/>			<!-- text content -->
				</xsl:when>
				<xsl:otherwise>
					<col />			<!-- text content -->
				</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
				<xsl:when test="$g_show_line_numbers">
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col style="width: 3em;"/>	<!-- line number -->
					<col style="width: 1em;"/>	<!-- spacer -->
					<col/>			<!-- text content -->
				</xsl:when>
				<xsl:otherwise>
					<col/>			<!-- text content -->
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
			</xsl:choose>
		</colgroup>
	<tr>
		<xsl:if test="$g_show_line_numbers">
			<xsl:for-each select="source[@role=1]">
				<xsl:call-template name="output-line_number">
					<xsl:with-param name="top">no</xsl:with-param>
					<xsl:with-param name="bottom">no</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:for-each select="source[@role=0]">
				<xsl:call-template name="output-line_number">
					<xsl:with-param name="top">no</xsl:with-param>
					<xsl:with-param name="bottom">no</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:for-each select="source[@role=2]">
				<xsl:call-template name="output-line_number">
					<xsl:with-param name="top">no</xsl:with-param>
					<xsl:with-param name="bottom">no</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:if>
		<td class="diffedtxt" >
			<xsl:apply-templates select="source[@role=1]/*" />
			
			<xsl:if test="string-length(.) = 0">
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
		</td>
		
	</tr></table>
	</td>
</xsl:template>

<xsl:template name="output-skipped-line">

	<td>
		<xsl:call-template name="single-cell-line-attrs">
			<xsl:with-param name="skipped">yes</xsl:with-param>
		</xsl:call-template>
		
		<xsl:choose>
		<xsl:when test="$g_show_skipped_lines">
			<xsl:call-template name="kg_skipped_lines">
				<xsl:with-param name="nb" select="@skipped" />
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="height">5</xsl:attribute>
		</xsl:otherwise>
		</xsl:choose>
	</td>
</xsl:template>

<xsl:template name="conflict-border">
<xsl:param name="left" />
<xsl:param name="right" />
<xsl:param name="top" />
<xsl:param name="bottom" />

	<xsl:if test="$left='yes'">
		<xsl:text>clb </xsl:text>
	</xsl:if>
	<xsl:if test="$right='yes'">
		<xsl:text>crb </xsl:text>
	</xsl:if>
	<xsl:if test="$top='yes'">
		<xsl:text>ctb </xsl:text>
	</xsl:if>
	<xsl:if test="$bottom='yes'">
		<xsl:text>cbb </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="details/line/source" mode="text-files">
<xsl:param name="left" />
<xsl:param name="right" />

	<xsl:choose>
	<xsl:when test="@empty='yes'">
		<td>
			<xsl:attribute name="class">
				<xsl:text>blank </xsl:text>
				<xsl:variable name="attr">
					<xsl:call-template name="conflict-border">
						<xsl:with-param name="left" select="$left" />
						<xsl:with-param name="right" select="$right" />
						<xsl:with-param name="top" select="../@conflict-start" />
						<xsl:with-param name="bottom" select="../@conflict-last" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="normalize-space($attr)" />
			</xsl:attribute>
			<xsl:choose>
			<xsl:when test="$g_show_line_numbers">
				<xsl:attribute name="colspan">3</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="colspan">2</xsl:attribute>
			</xsl:otherwise>
			</xsl:choose>
			<xsl:text>&#160;</xsl:text>
		</td>
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="output-line_number">
			<xsl:with-param name="left" select="$left" />
		</xsl:call-template>
		<td>
			<xsl:attribute name="class">
				<xsl:variable name="attr">
					<xsl:text>diffedtxt </xsl:text>
					<xsl:call-template name="conflict-border">
						<xsl:with-param name="right" select="$right" />
						<xsl:with-param name="top" select="../@conflict-start" />
						<xsl:with-param name="bottom" select="../@conflict-last" />
					</xsl:call-template>
					<xsl:choose>
					<!-- span/@class means that the diff at hand -really- have in line diffs
						when treating changes as insertions/deletions, they also can have
						inline diffs
					<xsl:when test="$g_use_inline_diff and span/@class">
						<xsl:variable name="left-action">
							<xsl:if test="not (translate(substring(span/@class,1,1), 'ARC', ''))">
								<xsl:value-of select="substring(@class, 1,1)"/>
							</xsl:if>
						</xsl:variable>
						<xsl:variable name="right-action">
							<xsl:if test="not (translate(span/@class, 'ARC', ''))">
								<xsl:value-of select="substring(@class, 1,1)"/>
							</xsl:if>
						</xsl:variable>
						 -->
					<xsl:when test="$g_use_inline_diff and contains(@class, 'C')">
						<!-- output spans for changed only lines -->
						
						<xsl:variable name="other-action" select="translate(@class, 'C', '')" />
						<xsl:if test="$other-action!=''">
							<xsl:value-of select="$other-action" /><xsl:text> </xsl:text>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@class" /><xsl:text> </xsl:text>
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:value-of select="normalize-space($attr)" />
			</xsl:attribute>
			
			<xsl:apply-templates />
			
			<xsl:if test="string-length(.) = 0">
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
		</td>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="span">

	<xsl:variable name="class_attr">
		<xsl:call-template name="span_attr_action" />
		<xsl:call-template name="span_attr_syntax" />
	</xsl:variable>
	
	<xsl:choose>
	<xsl:when test="$class_attr = ''">
		<xsl:apply-templates />
	</xsl:when>
	<xsl:otherwise>
		<span class="{normalize-space($class_attr)}">
			<xsl:apply-templates />
		</span>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="span_action" />
<xsl:template name="span_syntax" />

<xsl:template name="span_attr_action">

	<xsl:if test="boolean(@class)">
		<xsl:choose>
		<xsl:when test="$g_use_inline_diff and $g_use_monochrome_css">
			<xsl:text>inline_</xsl:text><xsl:value-of select="@class" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="@class" />
		</xsl:otherwise>
		</xsl:choose>
		<xsl:text> </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="span_attr_syntax">
<xsl:variable name="current_report_node" select="ancestor::comparison-export" />
<xsl:variable name="style_node" select="$current_report_node/options/styles" />
<xsl:variable name="lexer" select="$style_node/@language" />

	<xsl:text>S</xsl:text><xsl:value-of select="$lexer" /><xsl:value-of select="@style" /><xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="s">

	<xsl:text>&#160;</xsl:text>
</xsl:template>

<xsl:template match="t">

	<xsl:call-template name="output_tab">
		<xsl:with-param name="count"><xsl:value-of select="@width" /></xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="output_tab">
<xsl:param name="count" />

	<xsl:if test="number($count) &gt; 0">
		<xsl:text>&#160;</xsl:text>
		<xsl:call-template name="output_tab">
			<xsl:with-param name="count">
				<xsl:value-of select="number($count - 1)" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="cr">

	<xsl:if test="$g_display_options_node/@display_line_endings='yes'">
		<xsl:call-template name="control_char">
			<xsl:with-param name="text">CR</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="lf">

	<xsl:if test="$g_display_options_node/@display_line_endings='yes'">
		<xsl:call-template name="control_char">
			<xsl:with-param name="text">LF</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="brk">
	<wbr/>
</xsl:template>

<xsl:template match="cc">

	<xsl:call-template name="control_char">
		<xsl:with-param name="text"><xsl:value-of select="@name"/></xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="control_char">
<xsl:param name="text" />

		<small>
			<span class="line_ending">
				<xsl:attribute name="style">
					<xsl:text>color: </xsl:text>
					<xsl:call-template name="control_char_colour" />
				</xsl:attribute>
				<xsl:value-of select="$text" />
			</span>
			<xsl:text> </xsl:text>
		</small>
</xsl:template>

<xsl:template name="control_char_colour">

	<xsl:choose>
	<xsl:when test="$g_use_external_css or $g_use_coloured_css">
		<xsl:variable name="current-class" select="translate(../@class, 'ACIRU', 'aciru')" />
		<xsl:variable name="color-node" select="$g_display_options_node/@*[name()=concat($current-class, '_text_bgcolor')]" />
	
		<xsl:choose>
		<xsl:when test="boolean($color-node)">
			<xsl:value-of select="$color-node"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>FFFFFF</xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:text>FFFFFF</xsl:text>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="output-line_number">
<xsl:param name="left" />
<xsl:param name="right" />
<xsl:param name="top" select="../@conflict-start" />
<xsl:param name="bottom" select="../@conflict-last" />

	<xsl:if test="$g_show_line_numbers">
		<td><!-- line number -->
			<xsl:attribute name="class">
				<xsl:variable name="attr">
					<xsl:value-of select="@class" /><xsl:text> </xsl:text>
					<xsl:call-template name="conflict-border">
						<xsl:with-param name="left" select="$left" />
						<xsl:with-param name="right" select="$right" />
						<xsl:with-param name="top" select="$top" />
						<xsl:with-param name="bottom" select="$bottom" />
					</xsl:call-template>
					<xsl:if test="$g_use_coloured_css">
						<xsl:text>line_nb </xsl:text>
						<xsl:if test="not($g_use_inline_diff)">
							<xsl:value-of select="@class" />
						</xsl:if>
					</xsl:if>
				</xsl:variable>
				<xsl:value-of select="normalize-space($attr)" />
			</xsl:attribute>
			
			<xsl:choose>
			<xsl:when test="@line_number &gt;= 0">
				<xsl:call-template name="formatted-number">
					<xsl:with-param name="text">
						<xsl:value-of select="@line_number + 1" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>&#160;</xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:if>
	<td><!-- spacer -->
		<xsl:attribute name="class">
			<xsl:variable name="attr">
				<xsl:call-template name="conflict-border">
					<xsl:with-param name="left">no</xsl:with-param>
					<xsl:with-param name="right">no</xsl:with-param>
					<xsl:with-param name="top" select="$top" />
					<xsl:with-param name="bottom" select="$bottom" />
				</xsl:call-template>
				<xsl:if test="not($g_use_monochrome_css)">
					<xsl:value-of select="@class" />
				</xsl:if>
			</xsl:variable>
			<xsl:value-of select="normalize-space($attr)" />
		</xsl:attribute>
		
		<xsl:choose>
		<xsl:when test="$g_use_monochrome_css">
			<xsl:call-template name="output-class-code">
				<xsl:with-param name="class" select="@class" />
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#160;</xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</td>
</xsl:template>

<xsl:template match="statistics" mode="text-files">

	<!-- title -->
	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
		<h2><xsl:value-of select="$kg_statistics_report_title" /></h2>
	</xsl:when>
	<xsl:otherwise>
		<br /><br />
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_statistics_title" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:otherwise>
	</xsl:choose>
	
	<!-- data table -->
	<xsl:call-template name="detailed_stats_for_text_files" />
</xsl:template>

<xsl:template name="detailed_stats_for_text_files">

	<h2>
		<xsl:choose>
		<xsl:when test="../@object-type='text-file'">
			<xsl:value-of select="$kg_statistics_detailed_one_text_title" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$kg_statistics_detailed_text_title" />
		</xsl:otherwise>
		</xsl:choose>
	</h2>
	<p>
		<div style="float:left; padding-right:10px;">
			<xsl:call-template name="statistics_details_text" />
		</div>
		<xsl:if test="$g_is_3way_comparison">
			<div style="float:left;">
				<!-- conflicts -->
				<xsl:call-template name="statistics_conflicts" />
				<xsl:text> </xsl:text> <!-- IE bug, clear does not work with empty floating spans -->
			</div>
		</xsl:if>
	</p>
	<br style="clear:both;" />
</xsl:template>

<xsl:template name="statistics_details_text">

	<xsl:value-of select="$kg_all_changes" /><br />
	<table>
		<xsl:choose>
		<xsl:when test="$g_is_stats_only">
			<xsl:attribute name="cellspacing">0</xsl:attribute>
			<xsl:attribute name="cellpadding">3</xsl:attribute>
			<xsl:attribute name="border">1px</xsl:attribute>
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="class">tablebox</xsl:attribute>
			<xsl:attribute name="cellspacing">1</xsl:attribute>
		</xsl:otherwise>
		</xsl:choose>
		
		<xsl:variable name="node_set" select="all/pair/granularity[@type='blocks' or @type='lines']" />
		<xsl:choose>
		<xsl:when test="$g_is_3way_comparison">
			<xsl:call-template name="statistics_table_header">
				<xsl:with-param name="pair_nodes" select="all/pair" />
				<xsl:with-param name="stats_nodes_count" select="count(all/pair[1]/granularity[@type='blocks' or @type='lines'])" />
				<xsl:with-param name="description_title"><xsl:value-of select="$kg_description" /></xsl:with-param>
				<xsl:with-param name="description_rowspan">2</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="statistics_table_header_data_types">
				<xsl:with-param name="stats_nodes" select="$node_set" />
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="statistics_table_header_data_types">
				<xsl:with-param name="empty_left_cell">yes</xsl:with-param>
				<xsl:with-param name="empty_left_cell_colspan">2</xsl:with-param>
				<xsl:with-param name="stats_nodes" select="$node_set" />
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
		</xsl:choose>

		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">unchanged</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">inserted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_inserted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">deleted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_deleted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
		<xsl:if test="$g_can_ignore">
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="$node_set" />
				<xsl:with-param name="attr_name">ignored</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_ignored_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
	</table>
</xsl:template>

<xsl:template name="statistics_conflicts_details_text">

	<xsl:if test="all/granularity[@type!='files']/@conflict &gt; 0">
		<xsl:call-template name="kg_merge_files_conflicts_description">
			<xsl:with-param name="nb" select="all/granularity[@type!='files']/@conflict" />
		</xsl:call-template>
		<table>
			<xsl:choose>
			<xsl:when test="$g_is_stats_only">
				<xsl:attribute name="cellspacing">0</xsl:attribute>
				<xsl:attribute name="cellpadding">3</xsl:attribute>
				<xsl:attribute name="border">1px</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="class">tablebox</xsl:attribute>
				<xsl:attribute name="cellspacing">1</xsl:attribute>
			</xsl:otherwise>
			</xsl:choose>

			<xsl:call-template name="statistics_table_header">
				<xsl:with-param name="pair_nodes" select="conflicts/*[name()!='granularity']" />
				<xsl:with-param name="stats_nodes_count" select="count(conflicts[1]/*[1]/granularity[@type='blocks' or @type='lines'])" />
				<xsl:with-param name="description_title"><xsl:value-of select="$kg_description" /></xsl:with-param>
				<xsl:with-param name="description_rowspan">2</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="statistics_table_header_data_types">
				<xsl:with-param name="stats_nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="statistics_conflicts_details_text_lines">
			</xsl:call-template>

			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="attr_name">unchanged</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="attr_name">inserted</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_inserted_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="attr_name">deleted</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_deleted_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="$g_can_ignore">
				<xsl:call-template name="statistics_data_line_per_diff_type">
					<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
					<xsl:with-param name="attr_name">ignored</xsl:with-param>
					<xsl:with-param name="rowspan">1</xsl:with-param>
					<xsl:with-param name="colspan">2</xsl:with-param>
					<xsl:with-param name="text1"><xsl:value-of select="$kg_ignored_items" /></xsl:with-param>
					<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
					<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="attr_name">changed</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
		</table>
	</xsl:if>
</xsl:template>

<xsl:template name="statistics_conflicts_details_text_lines">

</xsl:template>

</xsl:stylesheet>
