﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:template name="metadata_bottom_images" />

<xsl:template name="metadata-image-item">
<xsl:param name="position" />
<xsl:param name="node" />

	<xsl:variable name="content-info-node" select="$node/../../content-info/*[name() = name($node)]" />

	<table class="tablebox" cellspacing="1">
		<xsl:if test="$position = 0"><xsl:attribute name="align">center</xsl:attribute></xsl:if>
		<tr>
			<td colspan="2" class="tablebox_header hth">
			<xsl:call-template name="source_role">
				<xsl:with-param name="source_idx"><xsl:value-of select="$position" /></xsl:with-param>
			</xsl:call-template>
			</td>
		</tr>
		<xsl:choose>
		<xsl:when test="boolean($node) and $node/last-metadata/@deleted!='yes'">
			<tr>
				<td colspan="2" class="hth">
					<xsl:choose>
					<xsl:when test="boolean($node/@title) and $node/@title != ''">
						<b><xsl:value-of select="$node/@title" /></b>
					</xsl:when>
					<xsl:otherwise>
						<b><xsl:apply-templates select="$node/url" /></b>
					</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_last_modified" /></td>
				<td>
					<span>
						<xsl:attribute name="title">
							<xsl:value-of select="$node/last-metadata/@modification-date" />
						</xsl:attribute>
						<xsl:value-of select="substring-before($node/last-metadata/@modification-date, '.')" />
					</span>
				</td>
			</tr>
			<tr>
				<td class="tablebox_header vth"><xsl:value-of select="$kg_size" /></td>
				<td>
					<xsl:call-template name="display-size">
						<xsl:with-param name="size" select="$node/last-metadata/@size" />
					</xsl:call-template>
				</td>
			</tr>
			<xsl:choose>
			<xsl:when test="../details/source[@role=$position]/state/@code=0">
				<tr>
					<td class="tablebox_header vth"><xsl:value-of select="$kg_image_dimensions" /></td>
					<td>
						<xsl:variable name="source" select="../details/source[@role=$position]" />
						<xsl:value-of select="$source/size/@x" /> * <xsl:value-of select="$source/size/@y" />
					</td>
				</tr>
				<xsl:call-template name="image-miniature">
					<xsl:with-param name="position" select="$position" />
					<xsl:with-param name="details_node" select="../details" />
					<xsl:with-param name="options_node" select="../options" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<tr>
					<td colspan="2">
						<div align="center">
							<xsl:value-of select="../details/source[@role=$position]/state/@description" />
						</div>
					</td>
				</tr>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<tr>
				<td colspan="2">
					<xsl:value-of select="$kg_missing_file" />
				</td>
			</tr>
		</xsl:otherwise>
		</xsl:choose>
	</table>
</xsl:template>

<xsl:template match="details" mode="images">
  
	<xsl:if test="$g_image_options_node/@reports_details = 'yes'">
	  <xsl:call-template name="display_heading">
		  <xsl:with-param name="text">
			  <xsl:value-of select="$kg_details_title" />
		  </xsl:with-param>
	  </xsl:call-template>
		<xsl:apply-templates select="pair" mode="images">
			<xsl:sort select="@roles" order="descending" />
		</xsl:apply-templates>
	</xsl:if>
</xsl:template>

<xsl:template match="details/pair" mode="images">

	<div style="padding-bottom:5px;">
	<table class="tablebox" width="100%">
		<xsl:variable name="current_role_pair" select="@roles" />
		<xsl:variable name="role_one">
			<xsl:value-of select="substring-before($current_role_pair, ',')" />
		</xsl:variable>
		<xsl:variable name="role_two">
			<xsl:value-of select="substring-after($current_role_pair, ',')" />
		</xsl:variable>

		<xsl:variable name="image_stats" select="../../statistics/all/pair[@roles=$current_role_pair]" />
		<xsl:variable name="image_are_different" select="$image_stats/granularity[@type='files-image']/@changed='1'" />

		<tr>
			<td class="tablebox_header" width="33%">
				<xsl:variable name="one">
					<xsl:call-template name="source_role">
						<xsl:with-param name="source_idx"><xsl:value-of select="$role_one" /></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="two">
					<xsl:call-template name="source_role">
						<xsl:with-param name="source_idx"><xsl:value-of select="$role_two" /></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="$one" /> - <xsl:value-of select="$two" />
			</td>
			<td width="33%">
				<xsl:choose>
				<xsl:when test="not(boolean($image_stats))">
					<xsl:text>&#160;</xsl:text>
				</xsl:when>
				<xsl:when test="$image_are_different">
					<xsl:value-of select="$kg_images_files_different" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$kg_images_files_identical" />
				</xsl:otherwise>
				</xsl:choose>
			</td>
			<td width="33%">
				<xsl:variable name="display_psnr" select="$g_image_options_node/@compute_psnr='yes'" />

				<xsl:choose>
				<xsl:when test="$display_psnr and $image_are_different">
					<b>PSNR</b> = <xsl:value-of select="@psnr" /> - <b>MSE</b> = <xsl:value-of select="@mse" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>&#160;</xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		<xsl:if test="$g_image_options_node/@display_difference_image=0 or ($image_are_different and $g_image_options_node/@display_difference_image=1)">
			<tr>
				<td colspan="3">
					<div style="float:left;padding:10px;">
						<xsl:call-template name="original-image">
							<xsl:with-param name="position" select="$role_one" />
							<xsl:with-param name="miniature">no</xsl:with-param>
							<xsl:with-param name="details_node" select=".." />
						</xsl:call-template>
					</div>
					<div style="float:left;padding:10px;"><img src="{@preview}" /></div>
					<div style="float:left;padding:10px;">
						<xsl:call-template name="original-image">
							<xsl:with-param name="position" select="$role_two" />
							<xsl:with-param name="miniature">no</xsl:with-param>
							<xsl:with-param name="details_node" select=".." />
						</xsl:call-template>
					</div>
				</td>
			</tr>
		</xsl:if>
	</table>
	</div>
</xsl:template>

<xsl:template name="image-miniature">
<xsl:param name="position" />
<xsl:param name="details_node" />
<xsl:param name="options_node" />

	<xsl:variable name="display_miniature" select="$g_image_options_node/@reports_show_miniatures='yes'" />
	<xsl:if test="$display_miniature">
		<tr>
			<td colspan="2">
				<div align="center">
					<xsl:call-template name="original-image">
						<xsl:with-param name="position" select="$position" />
						<xsl:with-param name="miniature">yes</xsl:with-param>
						<xsl:with-param name="details_node" select="$details_node" />
					</xsl:call-template>
				</div>
			</td>
		</tr>
	</xsl:if>
</xsl:template>

<xsl:template name="original-image">
<xsl:param name="position" />
<xsl:param name="miniature" />
<xsl:param name="details_node" />

	<img>
		<xsl:variable name="source_node" select="$details_node/source[@role=$position]" />
		<xsl:attribute name="src">
			<xsl:value-of select="$source_node/@src" />
		</xsl:attribute>

		<xsl:choose>
		<xsl:when test="$miniature = 'yes'">
			<xsl:attribute name="width">
				<xsl:value-of select="$source_node/miniature-size/@x" />
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$source_node/miniature-size/@y" />
			</xsl:attribute>
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="width">
				<xsl:value-of select="$source_node/preview-size/@x" />
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$source_node/preview-size/@y" />
			</xsl:attribute>
		</xsl:otherwise>
		</xsl:choose>
	</img>
</xsl:template>

<xsl:template match="statistics" mode="images">

	<xsl:if test="$g_image_options_node/@reports_summary='yes' and boolean(all)">
		<!-- title -->
		<xsl:choose>
		<xsl:when test="$g_is_stats_only">
			<h2><xsl:value-of select="$kg_statistics_report_title" /></h2>
		</xsl:when>
		<xsl:otherwise>
			<br /><br />
			<xsl:call-template name="display_heading">
				<xsl:with-param name="text">
					<xsl:value-of select="$kg_statistics_title" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
		</xsl:choose>
		
		<!-- data table -->
		<xsl:call-template name="detailed_stats_for_image_files" />
	</xsl:if>
</xsl:template>

<xsl:template name="detailed_stats_for_image_files">

	<br />
	<h2>
		<xsl:choose>
		<xsl:when test="../@object-type='image-file'">
			<xsl:value-of select="$kg_statistics_detailed_one_image_title" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$kg_statistics_detailed_image_title" />
		</xsl:otherwise>
		</xsl:choose>
	</h2>
	<p>
		<div style="float:left; padding-right:10px;">
			<xsl:call-template name="statistics_details_image" />
		</div>
	</p>
	<br style="clear:both;" />
</xsl:template>

<xsl:template name="statistics_details_image">

	<xsl:value-of select="$kg_all_changes" /><br />
	<table>
		<xsl:choose>
		<xsl:when test="$g_is_stats_only">
			<xsl:attribute name="cellspacing">0</xsl:attribute>
			<xsl:attribute name="cellpadding">3</xsl:attribute>
			<xsl:attribute name="border">1px</xsl:attribute>
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="class">tablebox</xsl:attribute>
			<xsl:attribute name="cellspacing">1</xsl:attribute>
		</xsl:otherwise>
		</xsl:choose>
		
		<xsl:variable name="node_set" select="all/pair/granularity[@type='image-dimensions' or @type='pixels']" />
		<xsl:choose>
		<xsl:when test="$g_is_3way_comparison">
			<xsl:call-template name="statistics_table_header">
				<xsl:with-param name="pair_nodes" select="all/pair" />
				<xsl:with-param name="stats_nodes_count" select="count(all/pair[1]/granularity[@type='image-dimensions' or @type='pixels'])" />
				<xsl:with-param name="description_title"><xsl:value-of select="$kg_description" /></xsl:with-param>
				<xsl:with-param name="description_rowspan">2</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="statistics_table_header_data_types">
				<xsl:with-param name="stats_nodes" select="$node_set" />
				<xsl:with-param name="types_subset">,image-dimensions,pixels,</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="statistics_table_header_data_types">
				<xsl:with-param name="empty_left_cell">yes</xsl:with-param>
				<xsl:with-param name="empty_left_cell_colspan">2</xsl:with-param>
				<xsl:with-param name="stats_nodes" select="$node_set" />
				<xsl:with-param name="types_subset">,image-dimensions,pixels,</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
		</xsl:choose>

		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">unchanged</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,image-dimensions,pixels,</xsl:with-param>
		</xsl:call-template>
		<xsl:if test="$g_can_ignore">
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="$node_set" />
				<xsl:with-param name="attr_name">similar</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_similar_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,image-dimensions,pixels,</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,image-dimensions,pixels,</xsl:with-param>
		</xsl:call-template>
	</table>
</xsl:template>

</xsl:stylesheet>
