<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:output method="xml" encoding="utf-8"/>

<!-- per-document report stylesheet -->
<xsl:include href="report-files.xsl" />
<xsl:include href="report-images.xsl" />
<xsl:include href="report-binary-files.xsl" />
<xsl:include href="report-eqtest-files.xsl" />
<xsl:include href="report-folders.xsl" />
<!-- common templates -->
<xsl:include href="all-reports-common.xsl" />

<!-- main section -->
<xsl:template match="/">

    <html>
    <head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<title>
			<!-- report title -->
			<xsl:choose>
			<xsl:when test="$g_is_stats_only">
				<xsl:value-of select="$kg_statistics_report_title" />
			</xsl:when>
			<xsl:when test="boolean(/comparison-export/@title)">
				<xsl:value-of select="/comparison-export/@title" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$kg_report_title" />
			</xsl:otherwise>
			</xsl:choose>
		</title>

		<xsl:if test="not($g_is_stats_only)">
			<xsl:call-template name="predefined_styles">
				<xsl:with-param name="options" select="/comparison-export/options" />
			</xsl:call-template>
		</xsl:if>
    </head>	

    <body>
		<!-- main section of the report -->
		<xsl:apply-templates select="/comparison-export" />

		<!-- for embedded files reports in folders reports -->
		<xsl:apply-templates select="/comparison-export/sub-reports" />

		<!-- footer -->
		<xsl:if test="not($g_top_level_comparison_type='binary-file')">
			<xsl:call-template name="legend" />
		</xsl:if>
		<p>
			<xsl:call-template name="kg_report_info" >
				<xsl:with-param name="date" select="/comparison-export/@date" />
			</xsl:call-template>
		</p>
    </body>
    </html>
</xsl:template>

<xsl:template match="comparison-export">

	<!-- title for sub-reports -->
	<xsl:if test="count(ancestor::*)&gt;0">
		<br />
		<a name="{../@id}" />
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_sub_report_title" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
  <xsl:if test="not($g_is_stats_only)">
	  <xsl:apply-templates select="metadata" />
	</xsl:if>

  <xsl:apply-templates select="statistics" />
 
  <xsl:if test="not($g_is_stats_only)">
	  <xsl:apply-templates select="details" />
	</xsl:if>
  
	<!-- output options only for top level comparison -->
  <xsl:if test="not($g_is_stats_only)">
	  <xsl:if test="count(ancestor::*)=0">
		  <xsl:apply-templates select="options" />
	  </xsl:if>
	</xsl:if>
</xsl:template>

<xsl:template name="predefined_styles">
<xsl:param name="options" />

	<xsl:choose>
	<xsl:when test="$g_use_external_css">
	<link rel="stylesheet" type="text/css" href="{$g_reports_options_node/@css_path}" />
	</xsl:when>
	<xsl:otherwise>
	<xsl:variable name="display_options" select="$options/display_options" />
	<xsl:variable name="text_display_options" select="$options/document_types/item[@key='texts']/value/display" />

		<style>
		body { background: #FFFFFF; color: #000000; margin: 5px, 5px, 5px, 5px; }
		body, h2, p, td, th { font-family: Verdana, Helvetica, Arial, sans-serif; text-align: left; }
		body, td, th { font-size: 60%; }
		h2 { font-size: 115%; }
		tr { vertical-align: middle; }
		th { background: #E6E6E6; text-align: center; }
		td { }
		blockquote { margin-left: 1em; margin-top: 0; margin-bottom: 0; }
		<xsl:choose>
		<xsl:when test="$g_use_coloured_css">
		.divbox { border:1px solid #E7DFC7; }
		.tablebox
		{
			BORDER: #E7DFC7 1px solid;
			BACKGROUND-COLOR: #FFFFFF;
			CELLPADDING: 5px;
		}
		.tablebox_td
		{
			BACKGROUND: #FFFFFF;
		}
		.tablebox_header
		{
			PADDING: 4px;
			BACKGROUND: #E7DFC7;
			COLOR: #B66532;
			FONT-WEIGHT: bold;
		}
		.heading { border:0px; cellpadding:0px; width=100%; clear:left;  }
		.divider_left { BACKGROUND-COLOR: #E7DFC7 }
		.divider_middle { COLOR: #ffffff; BACKGROUND-COLOR: #B66532; }
		.divider_right { BACKGROUND-COLOR: #E7DFC7 }
		</xsl:when>
		<xsl:otherwise>
		.divbox { border:1px solid #969696; }
		.tablebox
		{
			BORDER: #969696 1px solid;
			BACKGROUND-COLOR: #FFFFFF;
			CELLPADDING: 5px;
		}
		.tablebox_td
		{
			BACKGROUND: #FFFFFF;
		}
		.tablebox_header
		{
			PADDING: 4px;
			BACKGROUND: #FFFFFF;
			COLOR: #000000;
			FONT-WEIGHT: bold;
		}
		.divider_left { BACKGROUND-COLOR: #FFFFFF }
		.divider_middle { COLOR: #ffffff; BACKGROUND-COLOR: #969696; }
		.divider_right { BACKGROUND-COLOR: #FFFFFF }
		</xsl:otherwise>
		</xsl:choose>
		table.details { border: 0px; table-layout: fixed; }
		table.details tr { vertical-align: top; }
		
		td.diffedtxt { color: <xsl:value-of select="$g_unchanged_text_fgcolor"/>; }
		
		.clb { border-left: 1px solid red; }
		.crb { border-right: 1px solid red; }
		.ctb { border-top: 1px solid red; }
		.cbb { border-bottom: 1px solid red; }
		.hth { text-align: center; }
		.vth { text-align: left; }
		.single_cell { text-align: center; }
		.line_nb { text-align: right; }
		.ch_count { text-align: center; }
		
		<xsl:choose>
		<xsl:when test="$g_use_coloured_css">
		<xsl:call-template name="diff-operation-all-styles">
			<xsl:with-param name="display_options" select="$display_options" />
			<xsl:with-param name="text_display_options" select="$text_display_options" />
		</xsl:call-template>
		<xsl:if test="$g_top_level_comparison_type='folder'">
		td.conflict { background-color: <xsl:value-of select="$display_options/@changed_text_bgcolor"/>; color: #FF0000; font-weight: bold; }
		span.conflict { color: #FF0000; }
		span.conflict a { color: #FF0000; }
		</xsl:if>
		td.blank { background-color: #F5F5F5; }
		</xsl:when>
		<xsl:otherwise>
		span.inline_CU, span.inline_CC, span.inline_CI, span.inline_CR { font-weight: bold; }
		span.inline_AU { text-decoration: underline; }
		span.inline_CR { font-weight: bold; text-decoration: line-through; }
		span.inline_RU, span.inline_RR { text-decoration: line-through; }
		<xsl:if test="$g_top_level_comparison_type='folder'">
		td.conflict { font-weight: bold; }
		</xsl:if>
		td.blank { background-color: #FFFFFF; }
		</xsl:otherwise>
		</xsl:choose>
		

		img.folder_icon {float: left; text-align: left; margin: -1px 2px 0px 0px;  height: 16px; width: 16px; border: none; vertical-align: top; background-color: transparent; }
		div.folder_icon {float: left; width: auto; }
		img.date_icon {margin: -1px 2px 0px 0px;  height: 16px; width: 16px; border: none; vertical-align: top; background-color: transparent; }
		.left {float: left;width: auto; }
		.right {float: right;width: auto; }
		span.line_ending { background-color: #000000; }
		td.skipped { background-color: #F5F5F5; }
		<xsl:if test="$g_top_level_comparison_type='text-file'">
			<xsl:apply-templates select="$options/styles" mode="css" />
		</xsl:if>
		<xsl:if test="$g_has_sub_reports">
			<xsl:for-each select="//options/styles">
				<xsl:sort select="@language" />
				
				<xsl:variable name="lexer" select="@language" />
				<xsl:if test="not(boolean(preceding-sibling)) or preceding-sibling/@language!=$lexer">
					<xsl:apply-templates select="." mode="css" />
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		</style>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="metadata">

	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
	<!-- no metadata in statistics only reports -->
	</xsl:when>
	<xsl:otherwise>
		<!-- section title -->
		<xsl:call-template name="metadata-title" />
		
		<table cellspacing="1" border="0">
		<tr>
			<!-- left source -->
			<td valign="top">
				<xsl:call-template name="metadata_source">
					<xsl:with-param name="node" select="left" />
					<xsl:with-param name="position" select="1" />
				</xsl:call-template>
			</td>
			<!-- right source -->
			<td valign="top">
				<xsl:call-template name="metadata_source">
					<xsl:with-param name="node" select="right" />
					<xsl:with-param name="position" select="2" />
				</xsl:call-template>
			</td>
		</tr>
		<xsl:if test="$g_is_3way_comparison">
			<tr>
				<!-- ancestor source -->
				<td colspan="2" valign="top">
					<xsl:call-template name="metadata_source">
						<xsl:with-param name="node" select="ancestor" />
						<xsl:with-param name="position" select="0" />
					</xsl:call-template>
				</td>
			</tr>
		</xsl:if>
		</table>
		<xsl:call-template name="metadata_bottom" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="options">
	
	<xsl:if test="$g_top_level_comparison_type='folder'">
		<xsl:call-template name="folder_comparison_options">
			<xsl:with-param name="node" select="$g_folder_comparison_options_node" />
		</xsl:call-template>
		<xsl:call-template name="folder_display_options">
			<xsl:with-param name="node" select="$g_folder_display_options_node" />
		</xsl:call-template>
	</xsl:if>
  <xsl:variable name="text-file-stats">
    <xsl:value-of select="sum(../statistics/all/pair/granularity[@type='files-text']/@changed) + sum(../statistics/all/pair/granularity[@type='files-text']/@unchanged)" />
  </xsl:variable>
	<xsl:if test="$text-file-stats &gt; 0 or $g_top_level_comparison_type='text-file'">
		<xsl:call-template name="file_comparison_options">
			<xsl:with-param name="node" select="$g_text_comparison_options_node" />
		</xsl:call-template>
	</xsl:if>
  <xsl:variable name="image-file-stats">
    <xsl:value-of select="sum(../statistics/all/pair/granularity[@type='files-image']/@changed) + sum(../statistics/all/pair/granularity[@type='files-image']/@unchanged)" />
  </xsl:variable>
	<xsl:if test="$image-file-stats &gt; 0 or $g_top_level_comparison_type='image-file'">
		<xsl:call-template name="image_comparison_options">
			<xsl:with-param name="node" select="$g_image_options_node" />
		</xsl:call-template>
	</xsl:if>
  <xsl:variable name="binary-file-stats">
    <xsl:value-of select="sum(../statistics/all/pair/granularity[@type='files-binary']/@changed) + sum(../statistics/all/pair/granularity[@type='files-binary']/@unchanged)" />
  </xsl:variable>
	<xsl:if test="$binary-file-stats &gt; 0 or $g_top_level_comparison_type='binary-file'">
		<xsl:call-template name="binary_comparison_options">
			<xsl:with-param name="node" select="$g_binary_options_node" />
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template name="file_comparison_options">
<xsl:param name="node" />

  <br />
  <xsl:call-template name="display_heading">
	  <xsl:with-param name="text">
		  <xsl:value-of select="$kg_text_comparison_options_title" />
	  </xsl:with-param>
  </xsl:call-template>
  <p>
	  <xsl:if test="boolean(//options/styles/@language_label)">
		  <b><xsl:value-of select="$kg_syntax_colouring_language_used" /></b><xsl:text>: </xsl:text>
		  <xsl:value-of select="//options/styles/@language_label" />
		  <br />
	  </xsl:if>
  <!-- match case -->
	  <b><xsl:value-of select="$kg_match_case" /></b><xsl:text>: </xsl:text>
	  <xsl:call-template name="output-yes-no">
		  <xsl:with-param name="text" select="$node/@match_case" />
	  </xsl:call-template>
	  <xsl:text>.</xsl:text>
	  <br/>
  <!-- match line endings -->
	  <b><xsl:value-of select="$kg_match_line_endings" /></b><xsl:text>: </xsl:text>
	  <xsl:call-template name="output-yes-no">
		  <xsl:with-param name="text" select="$node/@match_line_endings" />
	  </xsl:call-template>
	  <xsl:text>.</xsl:text>
	  <br/>
  <!-- match whitespaces -->
	  <b><xsl:value-of select="$kg_match_whitespaces" /></b>
	  <blockquote>
		  <b><xsl:value-of select="$kg_ws_start" /></b><xsl:text>: </xsl:text>
		  <xsl:call-template name="output-yes-no">
			  <xsl:with-param name="text" select="$node/@match_whitespaces_at_start" />
		  </xsl:call-template>
		  <xsl:text>,</xsl:text><br/>
		  <b><xsl:value-of select="$kg_ws_middle" /></b><xsl:text>: </xsl:text>
		  <xsl:call-template name="output-yes-no">
			  <xsl:with-param name="text" select="$node/@match_whitespaces_in_middle" />
		  </xsl:call-template>
		  <xsl:text>,</xsl:text><br/>
		  <b><xsl:value-of select="$kg_ws_end" /></b><xsl:text>: </xsl:text>
		  <xsl:call-template name="output-yes-no">
			  <xsl:with-param name="text" select="$node/@match_whitespaces_at_end" />
		  </xsl:call-template>
		  <xsl:text>.</xsl:text>
	  </blockquote>
	  <!-- blank lines as empty lines -->
	  <b><xsl:value-of select="$kg_blank_lines_empty" /></b><xsl:text>: </xsl:text>
	  <xsl:call-template name="output-yes-no">
		  <xsl:with-param name="text" select="$node/@blank_lines_as_empty_lines" />
	  </xsl:call-template>
	  <xsl:text>.</xsl:text>
	  <br/>
	  <!-- in-line differences -->
	  <b><xsl:value-of select="$kg_in_line_diff_algo" /></b>
	  <blockquote>
	  <b><xsl:value-of select="$kg_in_line_word" /></b><xsl:text>: </xsl:text>
	  <xsl:call-template name="output-yes-no">
		  <xsl:with-param name="text" select="$node/@line_level" />
	  </xsl:call-template>
	  <xsl:text>,</xsl:text><br/>
	  <b><xsl:value-of select="$kg_in_line_char" /></b><xsl:text>: </xsl:text>
	  <xsl:call-template name="output-yes-no">
		  <xsl:with-param name="text" select="$node/@char_level" />
	  </xsl:call-template>
	  <xsl:text>.</xsl:text>
	  </blockquote>
  <xsl:if test="@ignore_line_changes_matching != ''">
	  <b><xsl:value-of select="$kg_ignore_line_changes_matching" /></b><xsl:text>: </xsl:text>
	  <xsl:value-of select="$node/@ignore_line_changes_matching" />
	  <xsl:text>.</xsl:text>
	  <br/>
  </xsl:if>
  <xsl:if test="$g_is_3way_comparison">
	  <!-- merges -->
	  <b><xsl:value-of select="$kg_surround_changes" /></b><xsl:text>: </xsl:text>
	  <xsl:choose>
	  <xsl:when test="$node/@security_space &gt; 0">
		  <xsl:call-template name="kg_security_distance">
			  <xsl:with-param name="line_nb" select="$node/@security_space" />
		  </xsl:call-template>
	  </xsl:when>
	  <xsl:when test="$node/@security_space = 0">
		  <xsl:value-of select="$kg_security_distance_only_overlap" />
	  </xsl:when>
	  <xsl:otherwise>
		  <xsl:value-of select="$kg_security_distance_all_changes" />
	  </xsl:otherwise>
	  </xsl:choose>
	  <br/>
  </xsl:if>
  </p>
</xsl:template>

<xsl:template match="display_options" />

<xsl:template name="folder_comparison_options">
<xsl:param name="node" />

	<br />
	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_folder_comparison_options_title" />
		</xsl:with-param>
	</xsl:call-template>
	<table class="tablebox" cellspacing="1">
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_depth" /></th>
			<td>
				<xsl:choose>
				<xsl:when test="$node/@recursive"><xsl:value-of select="$kg_folder_depth_all" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="$kg_folder_depth_one" /></xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_size_criteria" /></th>
			<td>
				<xsl:if test="$node/@use_size">
					<xsl:value-of select="$kg_folder_diff_size_diff_files" /><br />
				</xsl:if>
				<xsl:if test="$node/@equal_size_mean_equal_files">
					<xsl:value-of select="$kg_folder_same_size_same_files" /><br />
				</xsl:if>
			</td>
		</tr>
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_date_criteria" /></th>
			<td>
				<xsl:if test="$node/@different_date_mean_different_files">
					<xsl:value-of select="$kg_folder_diff_date_diff_files" /><br />
				</xsl:if>
				<xsl:if test="$node/@equal_date_mean_equal_files">
					<xsl:value-of select="$kg_folder_same_date_same_files" /><br />
					<xsl:if test="$node/@equal_date_and_size_mean_equal_files">
						<xsl:text>(</xsl:text>
						<xsl:value-of select="$kg_folder_same_date_and_size_same_files" />
						<xsl:text>)</xsl:text><br />
					</xsl:if>
				</xsl:if>
			</td>
		</tr>
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_fs_precision" /></th>
			<td>
				<xsl:if test="$node/@compensate_fs_precision_loss">
					<xsl:value-of select="$kg_folder_compensate_fs_precision_loss" /><br />
				</xsl:if>
				<xsl:call-template name="kg_folders_date_comparison_method">
					<xsl:with-param name="type" select="$node/@date_comparison_method" />
					<xsl:with-param name="date_diff" select="$node/@date_diff" />
				</xsl:call-template>
				<br />
			</td>
		</tr>
	</table>
	<br/>
	
	<xsl:call-template name="filters_options">
		<xsl:with-param name="filters_node" select="$node/filters_options" />
	</xsl:call-template>
</xsl:template>

<xsl:template name="filters_options">
<xsl:param name="filters_node" />

	<h2><xsl:value-of select="$kg_folder_filters_options_title" /></h2>
	<xsl:call-template name="display_file_name_filters">
		<xsl:with-param name="node" select="$filters_node" />
	</xsl:call-template>
	<xsl:call-template name="display_file_status_filters">
		<xsl:with-param name="node" select="$filters_node" />
	</xsl:call-template>
	<xsl:call-template name="display_file_date_filters">
		<xsl:with-param name="node" select="$filters_node" />
	</xsl:call-template>
</xsl:template>

<xsl:template name="folder_display_options">
<xsl:param name="node" />

	<h2><xsl:value-of select="$kg_folder_display_options_title" /></h2>
	<table class="tablebox" cellspacing="1">
	<tr>
		<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_show_size" /></th>
		<td>
			<xsl:call-template name="output-yes-no">
				<xsl:with-param name="text" select="$node/@show_size" />
			</xsl:call-template>
		</td>
	</tr>
	<tr>
		<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_show_date" /></th>
		<td>
			<xsl:call-template name="output-yes-no">
				<xsl:with-param name="text" select="$node/@show_date" />
			</xsl:call-template>
		</td>
	</tr>
	<tr>
		<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_show_diff_count" /></th>
		<td>
			<xsl:call-template name="output-yes-no">
				<xsl:with-param name="text" select="$node/@show_diffcount" />
			</xsl:call-template>
		</td>
	</tr>
	</table>
</xsl:template>

<xsl:template name="image_comparison_options">
<xsl:param name="node" />

	<br />
	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_image_comparison_options_title" />
		</xsl:with-param>
	</xsl:call-template>
	<p>
		<b><xsl:value-of select="$kg_image_exact_threshold" /></b><xsl:text>: </xsl:text>
		<xsl:value-of select="$node/@exactness_threshold" />
		<br />
		<b><xsl:value-of select="$kg_image_difference_threshold" /></b><xsl:text>: </xsl:text>
		<xsl:value-of select="$node/@difference_threshold" />
	</p>
</xsl:template>

<xsl:template name="binary_comparison_options">
<xsl:param name="node" />

	<br />
	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_binary_comparison_options_title" />
		</xsl:with-param>
	</xsl:call-template>
	<p>
		<b><xsl:value-of select="$kg_binary_max_distance" /></b><xsl:text>: </xsl:text>
		<xsl:value-of select="$node/comparison/@max_resync_distance" /><xsl:text> </xsl:text><xsl:value-of select="$kg_bytes"/>
		<br />
		<b><xsl:value-of select="$kg_binary_min_match" /></b><xsl:text>: </xsl:text>
		<xsl:value-of select="$node/comparison/@minimal_match" /><xsl:text> </xsl:text><xsl:value-of select="$kg_bytes"/>
	</p>
</xsl:template>

<xsl:template match="statistics/all">

	<h2><xsl:value-of select="$kg_statistics_global_title" /></h2>
	<table>
		<xsl:choose>
		<xsl:when test="$g_is_stats_only">
			<xsl:attribute name="cellspacing">0</xsl:attribute>
			<xsl:attribute name="cellpadding">3</xsl:attribute>
			<xsl:attribute name="border">1px</xsl:attribute>
		</xsl:when>
		<xsl:otherwise>
			<xsl:attribute name="class">tablebox</xsl:attribute>
			<xsl:attribute name="cellspacing">1</xsl:attribute>
		</xsl:otherwise>
		</xsl:choose>

		<xsl:call-template name="statistics_table_header">
			<xsl:with-param name="pair_nodes" select="pair" />
			<xsl:with-param name="stats_nodes_count">0</xsl:with-param>
			<xsl:with-param name="description_title"><xsl:value-of select="$kg_files_and_folders" /></xsl:with-param>
			<xsl:with-param name="description_rowspan">1</xsl:with-param>
		</xsl:call-template>

		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
			<xsl:with-param name="attr_name">unchanged</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,files,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
			<xsl:with-param name="attr_name">inserted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_inserted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,files,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
			<xsl:with-param name="attr_name">deleted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_deleted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,files,</xsl:with-param>
		</xsl:call-template>
		
		<!-- changed files -->
		<xsl:variable name="file_types" select="count(pair[1]/granularity[starts-with(@type, 'files-')])" />
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="rowspan"><xsl:value-of select="number($file_types) + 1" /></xsl:with-param> <!-- computed from the number of handled file types -->
			<xsl:with-param name="colspan">1</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
			<xsl:with-param name="text2"><xsl:value-of select="$kg_all_files" />*</xsl:with-param>
			<xsl:with-param name="types_subset">,files,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files-text']" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="text2">
				<xsl:call-template name="output-granularity-type">
					<xsl:with-param name="text">files-text</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="types_subset">,files-text,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files-image']" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="text2">
				<xsl:call-template name="output-granularity-type">
					<xsl:with-param name="text">files-image</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="types_subset">,files-image,</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="pair/granularity[@type='files-binary']" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="text2">
				<xsl:call-template name="output-granularity-type">
					<xsl:with-param name="text">files-binary</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="types_subset">,files-binary,</xsl:with-param>
		</xsl:call-template>
	</table>
	<b>*</b><small> <xsl:value-of select="$kg_all_files_explanation" /></small>
	<br />
	<xsl:if test="granularity[@type='files']/@conflicting &gt; 0">
		<p>
			<xsl:call-template name="kg_merge_folders_with_conflicts">
				<xsl:with-param name="nb" select="granularity[@type='files']/@conflicting" />
			</xsl:call-template>
		</p>
	</xsl:if>
</xsl:template>

<xsl:template name="statistics_data_line_per_diff_type">
<xsl:param name="nodes" />
<xsl:param name="attr_name" />
<xsl:param name="rowspan" />
<xsl:param name="colspan" />
<xsl:param name="text1" />
<xsl:param name="text2" />
<xsl:param name="types_subset" />
<xsl:param name="empty_col_before_01" select="'yes'" />

	<tr>
		<xsl:if test="string-length($text1) &gt; 0">
			<td rowspan="{$rowspan}" colspan="{$colspan}" valign="middle">
				<xsl:value-of select="$text1" />
			</td>
		</xsl:if>
		<xsl:if test="string-length($text2) &gt; 0">
			<td colspan="{$colspan}">
				<xsl:value-of select="$text2" />
			</td>
		</xsl:if>
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$nodes" />
			<xsl:with-param name="attr_name" select="$attr_name" />
			<xsl:with-param name="types_subset" select="$types_subset" />
			<xsl:with-param name="empty_col_before_01" select="$empty_col_before_01" />
		</xsl:call-template>
	</tr>
</xsl:template>

<xsl:template name="statistics_data_per_type">
<xsl:param name="nodes" />
<xsl:param name="attr_name" />
<xsl:param name="types_subset" /> <!-- formatted as ",a,b,c," -->
<xsl:param name="empty_col_before_01" select="'yes'" />

	<xsl:for-each select="$nodes">
		<xsl:sort select="substring-before(../@roles, ',')" order="descending" />
		<xsl:sort select="substring-after(../@roles, ',')" order="ascending" />
		
		<xsl:variable name="node_type"><xsl:value-of select="concat(',', concat(@type, ','))" /></xsl:variable>
		<xsl:if test="$empty_col_before_01 = 'yes' and ../@roles='0,1' and starts-with($types_subset, $node_type)">
			<td style="width: 1em;">&#160;</td>
		</xsl:if>
		
		<td>
			<xsl:choose>
			<xsl:when test="$g_is_stats_only">
				<xsl:attribute name="align">center</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="style">text-align: center;</xsl:attribute>
			</xsl:otherwise>
			</xsl:choose>
			<xsl:variable name="attr_text">
				<xsl:call-template name="attribute_by_name">
					<xsl:with-param name="node" select="." />
					<xsl:with-param name="name" select="$attr_name" />
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
			<xsl:when test="string-length($attr_text) &gt; 0">
				<xsl:value-of select="$attr_text" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>&#160;</xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:for-each>
</xsl:template>

<xsl:template name="statistics_table_header">
<xsl:param name="pair_nodes" />
<xsl:param name="stats_nodes_count" />
<xsl:param name="description_title" />
<xsl:param name="description_rowspan" />
<xsl:param name="empty_col_before_01" select="'yes'" />

	<tr>
		<th rowspan="{$description_rowspan}" colspan="2" valign="bottom">
			<xsl:if test="not($g_is_stats_only)"><xsl:attribute name="class">tablebox_header</xsl:attribute></xsl:if>
			<xsl:value-of select="$description_title" />
		</th>
		
		<xsl:for-each select="$pair_nodes">
			<xsl:sort select="substring-before(@roles, ',')" order="descending" />
			<xsl:sort select="substring-after(@roles, ',')" order="ascending" />

			<xsl:if test="$empty_col_before_01='yes' and @roles='0,1'">
				<td style="width: 1em;">&#160;</td>
			</xsl:if>

			<th colspan="{$stats_nodes_count}">
				<xsl:choose>
				<xsl:when test="$g_is_stats_only">
					<xsl:attribute name="bgcolor">#E6E6E6</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">tablebox_header</xsl:attribute>
				</xsl:otherwise>
				</xsl:choose>
				
				<xsl:variable name="one">
					<xsl:call-template name="source_role">
						<xsl:with-param name="source_idx"><xsl:value-of select="substring-before(@roles, ',')" /></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="two">
					<xsl:call-template name="source_role">
						<xsl:with-param name="source_idx"><xsl:value-of select="substring-after(@roles, ',')" /></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:call-template name="kg_statistics_pair_info">
					<xsl:with-param name="one" select="$one" />
					<xsl:with-param name="two" select="$two" />
				</xsl:call-template>
			</th>
		</xsl:for-each>
	</tr>
</xsl:template>

<xsl:template name="statistics_table_header_data_types">
<xsl:param name="empty_left_cell" />
<xsl:param name="empty_left_cell_colspan" />
<xsl:param name="stats_nodes" />
<xsl:param name="types_subset" /> <!-- formatted as ",a,b,c," -->
<xsl:param name="empty_col_before_01" select="'yes'" />

	<tr>
		<xsl:if test="$empty_left_cell = 'yes'">
			<th colspan="{$empty_left_cell_colspan}">
				<xsl:if test="not($g_is_stats_only)"><xsl:attribute name="class">tablebox_header</xsl:attribute></xsl:if>
				<xsl:text>&#160;</xsl:text>
			</th>
		</xsl:if>
		
		<xsl:for-each select="$stats_nodes">
			<xsl:sort select="substring-before(../@roles, ',')" order="descending" />
			<xsl:sort select="substring-after(../@roles, ',')" order="ascending" />

			<xsl:variable name="node_type"><xsl:value-of select="concat(',', concat(@type, ','))" /></xsl:variable>
			<xsl:if test="$empty_col_before_01 = 'yes' and ../@roles='0,1' and starts-with($types_subset, $node_type)">
				<td style="width: 1em;">&#160;</td>
			</xsl:if>
			<th>
				<xsl:choose>
				<xsl:when test="$g_is_stats_only">
					<xsl:attribute name="bgcolor">#E6E6E6</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">tablebox_header</xsl:attribute>
				</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="output-granularity-type">
					<xsl:with-param name="text" select="@type" />
				</xsl:call-template>
			</th>
		</xsl:for-each>
	</tr>
</xsl:template>

<xsl:template name="statistics_table_content">
<xsl:param name="stats_nodes" />

	<tr>
		<td colspan="2"><xsl:value-of select="$kg_unchanged_items" /></td>
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$stats_nodes" />
			<xsl:with-param name="attr_name">unchanged</xsl:with-param>
		</xsl:call-template>
	</tr>
	<tr>
		<td colspan="2"><xsl:value-of select="$kg_inserted_items" /></td>
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$stats_nodes" />
			<xsl:with-param name="attr_name">inserted</xsl:with-param>
		</xsl:call-template>
	</tr>
	<tr>
		<td colspan="2"><xsl:value-of select="$kg_deleted_items" /></td>
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$stats_nodes" />
			<xsl:with-param name="attr_name">deleted</xsl:with-param>
		</xsl:call-template>
	</tr>
	<tr>
		<td colspan="2"><xsl:value-of select="$kg_changed_items" /></td>
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$stats_nodes" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
		</xsl:call-template>
	</tr>
	<xsl:if test="$g_can_ignore and $stats_nodes/@type!='files'">
		<tr>
			<td colspan="2"><xsl:value-of select="$kg_ignored_items" /></td>
			<xsl:call-template name="statistics_data_per_type">
				<xsl:with-param name="nodes" select="$stats_nodes" />
				<xsl:with-param name="attr_name">ignored</xsl:with-param>
			</xsl:call-template>
		</tr>
	</xsl:if>
</xsl:template>

<xsl:template match="details">

	<br /><br />
	<xsl:call-template name="details-common" />
</xsl:template>

<xsl:template match="sub-reports">

	<xsl:for-each select="sub-report/comparison-export">
		<hr />
		<xsl:apply-templates select="." />
	</xsl:for-each>
	<hr />
</xsl:template>

<xsl:template name="output-legend">

	<br />
	<xsl:call-template name="output-legend-title" />

	<table class="tablebox" cellspacing="1">
		<xsl:choose>
		<xsl:when test="$g_use_monochrome_css">
			<tr>
				<td>
					<xsl:call-template name="output-class-code">
						<xsl:with-param name="class">UU</xsl:with-param>
					</xsl:call-template>
				</td>
				<td><xsl:value-of select="$kg_unchanged_sample" /></td>
			</tr>
			<tr>
				<td>
					<xsl:call-template name="output-class-code">
						<xsl:with-param name="class">CU</xsl:with-param>
					</xsl:call-template>
				</td>
				<td><xsl:value-of select="$kg_changed_sample" /></td>
			</tr>
			<xsl:if test="$g_top_level_comparison_type='folder'">
				<tr>
					<td> </td>
					<td class="conflict"><xsl:value-of select="$kg_conflicting_sample" /></td>
				</tr>
			</xsl:if>
			<tr>
				<td>
					<xsl:call-template name="output-class-code">
						<xsl:with-param name="class">AU</xsl:with-param>
					</xsl:call-template>
				</td>
				<td><xsl:value-of select="$kg_inserted_sample" /></td>
			</tr>
			<tr>
				<td>
					<xsl:call-template name="output-class-code">
						<xsl:with-param name="class">RU</xsl:with-param>
					</xsl:call-template>
				</td>
				<td><xsl:value-of select="$kg_deleted_sample" /></td>
			</tr>
			<xsl:if test="$g_can_ignore">
				<tr>
					<td>
						<xsl:call-template name="output-class-code">
							<xsl:with-param name="class">IU</xsl:with-param>
						</xsl:call-template>
					</td>
					<td><xsl:value-of select="$kg_ignored_sample" /></td>
				</tr>
			</xsl:if>
			<xsl:if test="$g_top_level_comparison_type='text-file' and $g_use_inline_diff">
				<tr>
					<td colspan="2"><span class="inline_CU"><xsl:value-of select="$kg_inline_changed_text" /></span></td>
				</tr>
				<tr>
					<td colspan="2"><span class="inline_AU"><xsl:value-of select="$kg_inline_inserted_text" /></span></td>
				</tr>
				<tr>
					<td colspan="2"><span class="inline_RU"><xsl:value-of select="$kg_inline_deleted_text" /></span></td>
				</tr>
			</xsl:if>
		</xsl:when>
		<xsl:otherwise>
			<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_unchanged_line" /> </th><td class="U"><xsl:value-of select="$kg_unchanged_sample" /></td></tr>
			<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_changed_line" /> </th><td class="C"><xsl:value-of select="$kg_changed_sample" /></td></tr>
			<xsl:if test="$g_top_level_comparison_type='folder'">
				<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_conflicting_line" /> </th><td class="conflict"><xsl:value-of select="$kg_conflicting_sample" /></td></tr>
			</xsl:if>
			<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_inserted_line" /> </th><td class="A"><xsl:value-of select="$kg_inserted_sample" /></td></tr>
			<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_deleted_line" /> </th><td class="R"><xsl:value-of select="$kg_deleted_sample" /></td></tr>
			<xsl:if test="$g_can_ignore">
				<tr><th class="tablebox_header vth"><xsl:value-of select="$kg_ignored_line" /> </th><td class="I"><xsl:value-of select="$kg_ignored_sample" /></td></tr>
			</xsl:if>
		</xsl:otherwise>
		</xsl:choose>
	</table>
</xsl:template>

<xsl:template name="output-class-code">
<xsl:param name="class" />

	<b>
		<xsl:call-template name="output-class-code-common">
			<xsl:with-param name="class" select="$class" />
		</xsl:call-template>
	</b>
</xsl:template>

<xsl:template match="styles" mode="css">

	<xsl:apply-templates mode="css" />
</xsl:template>

<xsl:template match="styles/style" mode="css">
<xsl:variable name="lexer" select="../@language" />

	<xsl:text>		span.S</xsl:text><xsl:value-of select="concat($lexer, @index)" /> { <xsl:apply-templates /><xsl:text>}
</xsl:text>
</xsl:template>

<xsl:template match="styles/style/font">

	<xsl:if test="string-length(@color) &gt; 0 and @color != '#000000'">
		<xsl:text>color: </xsl:text><xsl:value-of select="@color" /><xsl:text>; </xsl:text>
	</xsl:if>
	<xsl:if test="@bold = 'yes'">
		<xsl:text>font-weight: bold; </xsl:text>
	</xsl:if>
	<xsl:if test="@italic = 'yes'">
		<xsl:text>font-style: italic; </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="use_file_name_filters">
<xsl:variable name="exclude_list">

	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@exclude_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@exclude_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="include_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@include_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@include_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

	<xsl:if test="$exclude_list">
		<xsl:text>yes</xsl:text>
	</xsl:if>
	<xsl:if test="$include_list">
		<xsl:text>yes</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="display_file_status_filters">
<xsl:param name="node" />

<xsl:variable name="ignore_missing" select="$node/@ignore_missing_in_source='yes' or $node/@ignore_missing_in_target='yes' or $node/@ignore_missing_in_ancestor='yes' or $node/@ignore_missing_in_result='yes'" />
<xsl:variable name="ignore_present" select="$node/@ignore_present_in_source='yes' or $node/@ignore_present_in_target='yes' or $node/@ignore_present_in_ancestor='yes' or $node/@ignore_present_in_result='yes'" />
<xsl:variable name="display" select="$node/@display_identical='no' or $node/@display_different='no' or $node/@display_conflicts='no'" />
<xsl:variable name="ignore" select="$node/@ignore_hidden='yes' or $node/@hide_empty_identical_folders='yes'" />

	<xsl:choose>
	<xsl:when test="$ignore_missing or $ignore_present or $display or $ignore">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_status_title" /></th>
		</tr>
		<xsl:if test="$ignore_missing">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_missing" /></th>
				<td>
					<xsl:if test="$node/@ignore_missing_in_source='yes'">
						<xsl:value-of select="$kg_folder_filters_in_source" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_missing_in_target='yes'">
						<xsl:value-of select="$kg_folder_filters_in_target" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_missing_in_ancestor='yes'">
						<xsl:value-of select="$kg_folder_filters_in_ancestor" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_missing_in_result='yes'">
						<xsl:value-of select="$kg_folder_filters_in_result" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="$ignore_present='yes'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_present" /></th>
				<td>
					<xsl:if test="$node/@ignore_present_in_source='yes'">
						<xsl:value-of select="$kg_folder_filters_in_source" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_present_in_target='yes'">
						<xsl:value-of select="$kg_folder_filters_in_target" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_present_in_ancestor='yes'">
						<xsl:value-of select="$kg_folder_filters_in_ancestor" /><br/>
					</xsl:if>
					<xsl:if test="$node/@ignore_present_in_result='yes'">
						<xsl:value-of select="$kg_folder_filters_in_result" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="$display='no'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_compared" /></th>
				<td>
					<xsl:if test="$node/@display_identical='no'">
						<xsl:value-of select="$kg_folder_filters_identical" /><br/>
					</xsl:if>
					<xsl:if test="$node/@display_different='no'">
						<xsl:value-of select="$kg_folder_filters_different" /><br/>
					</xsl:if>
					<xsl:if test="$node/@display_conflicts='no'">
						<xsl:value-of select="$kg_folder_filters_conflicting" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="$ignore='yes'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_others" /></th>
				<td>
					<xsl:if test="$node/@ignore_hidden='yes'">
						<xsl:value-of select="$kg_folder_filters_hide_system_hidden" /><br />
					</xsl:if>
					<xsl:if test="$node/@hide_empty_identical_folders='yes'">
						<xsl:value-of select="$kg_folder_filters_hide_empty_identical_folders" /><br />
					</xsl:if>					
				</td>
			</tr>
		</xsl:if>
		</table>
		<br/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_status" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display_file_date_filters">
<xsl:param name="node" />

	<xsl:choose>
	<xsl:when test="$node/@use_date_filter='yes'">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_filedate_title" /></th>
		</tr>
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_exclude_files_by_date_title" /></th>
			<td>
				<xsl:call-template name="kg_folder_filters_exclude_files_by_date">
					<xsl:with-param name="before" select="$node/@date_filter_exclude_files_before" />
					<xsl:with-param name="nb_days" select="$node/@days_number" />
					<xsl:with-param name="date" select="$node/@day_cutoff" />
					<xsl:with-param name="use_date" select="$node/@date_filter_use_calendar" />
				</xsl:call-template>
			</td>
		</tr>
		<xsl:if test="$node/@date_filter_if_all_sources='yes'">
			<tr>
				<td colspan="2"><xsl:value-of select="$kg_folder_filters_exclude_files_if_everywhere" /></td>
			</tr>
		</xsl:if>
		</table>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_filedate" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display_file_name_filters">
<xsl:param name="node" />

<xsl:variable name="exclude_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="$node/three_way/@exclude_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$node/two_way/@exclude_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="include_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="$node/three_way/@include_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$node/two_way/@include_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

	<xsl:choose>
	<xsl:when test="string-length($include_list) &gt; 0 or string-length($exclude_list) &gt; 0">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_filename_title" /></th>
		</tr>
		<xsl:if test="string-length($include_list) &gt; 0">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_filename_include" /></th>
				<td><xsl:value-of select="$include_list" /></td>
			</tr>
		</xsl:if>
		<xsl:if test="string-length($exclude_list) &gt; 0">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_filename_exclude" /></th>
				<td><xsl:value-of select="$exclude_list" /></td>
			</tr>
		</xsl:if>
		</table>
		<br/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_filename" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="diff-operation-all-styles">
<!-- colours are taken from there (back/foreground) -->
<xsl:param name="display_options" />
<!-- infos for text decoration -->
<xsl:param name="text_display_options" />

	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">AA</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>

	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">A</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">C</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">I</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">R</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">U</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">AC</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">AI</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">AR</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">AU</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">CC</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">CI</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">CR</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">CU</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">II</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">IR</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">IU</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">RR</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
	<xsl:call-template name="diff-operation-style2">
		<xsl:with-param name="code">RU</xsl:with-param>
		<xsl:with-param name="colour_node" select="$display_options" />
		<xsl:with-param name="decorations_node" select="$text_display_options" />
	</xsl:call-template>
</xsl:template>

<xsl:template name="text-diff-deco-style-prefix">
<xsl:param name="lcode"/>

<xsl:choose>
	<xsl:when test="$lcode='a'"><xsl:text>inserted</xsl:text></xsl:when>
	<xsl:when test="$lcode='r'"><xsl:text>deleted</xsl:text></xsl:when>
	<xsl:when test="$lcode='c'"><xsl:text>changed</xsl:text></xsl:when>
	<xsl:when test="$lcode='i'"><xsl:text>ignored_change</xsl:text></xsl:when>
</xsl:choose>

</xsl:template>

<!--
background colour
foreground colour
underline
striked
-->
<xsl:template name="diff-operation-style2">
<xsl:param name="code" />
<xsl:param name="colour_node" />
<xsl:param name="decorations_node" />

	<!-- lcode = to_lower(code)[to_lower(code)] -->
	<xsl:variable name="lcode">
		<xsl:variable name="lcode_sd">
			<xsl:call-template name="string-lower"><xsl:with-param name="text" select="$code" /></xsl:call-template>
		</xsl:variable>
			
		<!-- mono letter (A,R...) are treated as double letter (AA,RR...) codes -->
		<xsl:choose>
			<xsl:when test="string-length($lcode_sd)=1">
				<!-- no mix just find the colour, the style and go on --> 
				<xsl:value-of select="$lcode_sd"/><xsl:value-of select="$lcode_sd"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$lcode_sd"/>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:variable>
	
	<xsl:variable name="decostyle1_prefix">
		<xsl:call-template name="text-diff-deco-style-prefix"><xsl:with-param name="lcode" select="substring($lcode,1,1)"/></xsl:call-template>
	</xsl:variable>
	<xsl:variable name="decostyle2_prefix">
		<xsl:call-template name="text-diff-deco-style-prefix"><xsl:with-param name="lcode" select="substring($lcode,2,1)"/></xsl:call-template>
	</xsl:variable>

	<!-- NB: a missing decostyle is perfectly acceptable and means:
			decorate as background only 
		for the pairs with Unchanged mix, it is OK -->
	<xsl:variable name="decostyle1"
		select="$decorations_node/*[name()=concat($decostyle1_prefix,'_text_decorations')]" />
	<xsl:variable name="decostyle2"
		select="$decorations_node/*[name()=concat($decostyle2_prefix,'_text_decorations')]" />
		
	<!-- the following variables are all computed the same way: find the applicable
		mix which apply, then get the parameter if any from that -->

	<xsl:variable name="underline"> <!-- if any as decoration='2' -->
		<xsl:if test="$decostyle1/@decoration_kind='2' or $decostyle2/@decoration_kind='2'">
			<xsl:text>text-decoration: underline; </xsl:text>
		</xsl:if>
	</xsl:variable>
	
	<xsl:variable name="linethrough">
		<xsl:if test="$decostyle1/@decoration_kind='3' or $decostyle2/@decoration_kind='3'">
			<xsl:text>text-decoration: line-through; </xsl:text>
		</xsl:if>
	</xsl:variable>
	
	<xsl:variable name="foreground">
		<xsl:variable name="with_foreground">
			<xsl:choose>
				<xsl:when test="$decostyle1/@do_colour_text='yes' and $decostyle2/@do_colour_text='yes'">
					<xsl:value-of select="$lcode"/>
				</xsl:when>
				<xsl:when test="$decostyle1/@do_colour_text='yes'">
					<xsl:value-of select="substring($lcode,1,1)"/><xsl:value-of select="substring($lcode,1,1)"/>
				</xsl:when>
				<xsl:when test="$decostyle2/@do_colour_text='yes'">
					<xsl:value-of select="substring($lcode,2,1)"/><xsl:value-of select="substring($lcode,2,1)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$with_foreground">
			<xsl:text>color: </xsl:text>
			<xsl:value-of select="$colour_node/@*[name()=concat($with_foreground, '_text_fgcolor')]"/>
			<xsl:text>; </xsl:text>
		</xsl:if>
	</xsl:variable>
	
	<xsl:variable name="background">
		<xsl:variable name="with_background">
			<xsl:choose>
				<xsl:when test="(not ($decostyle1) or $decostyle1/@decoration_kind='1') and (not ($decostyle2) or $decostyle2/@decoration_kind='1')">
					<xsl:value-of select="$lcode"/>
				</xsl:when>
				<xsl:when test="(not ($decostyle1) or $decostyle1/@decoration_kind='1')">
					<xsl:value-of select="substring($lcode,1,1)"/><xsl:text>u</xsl:text>
				</xsl:when>
				<xsl:when test="(not ($decostyle2) or $decostyle2/@decoration_kind='1')">
					<xsl:value-of select="substring($lcode,2,1)"/><xsl:text>u</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$with_background and $with_background!='uu'"><!-- uu happens for 'only foreground' stuff -->
			<xsl:text>background-color: </xsl:text>
			<xsl:value-of select="$colour_node/@*[name()=concat($with_background, '_text_bgcolor')]"/>
			<xsl:text>; </xsl:text>
		</xsl:if>
	</xsl:variable>
	

	<xsl:text>td.</xsl:text><xsl:value-of select="$code" />
	<xsl:text> { </xsl:text>
	<xsl:value-of select="$underline" />
	<xsl:value-of select="$linethrough" />
	<xsl:value-of select="$foreground" />
	<xsl:value-of select="$background" />
	<xsl:text> }
		span.</xsl:text><xsl:value-of select="$code" />
	<xsl:text> { </xsl:text>
	<xsl:value-of select="$underline" />
	<xsl:value-of select="$linethrough" />
	<xsl:value-of select="$foreground" />
	<xsl:value-of select="$background" />
	<xsl:text> }
		</xsl:text>
</xsl:template>

<xsl:template name="diff-operation-style">
<xsl:param name="code" />
<xsl:param name="bgcolour" />

	<xsl:text>td.</xsl:text><xsl:value-of select="$code" />
	<xsl:text> { background-color: </xsl:text>
	<xsl:value-of select="$bgcolour"/>
	<xsl:text>; }
		span.</xsl:text><xsl:value-of select="$code" />
	<xsl:text> { background-color: </xsl:text>
	<xsl:value-of select="$bgcolour"/>
	<xsl:text>; }
		</xsl:text>
</xsl:template>

<xsl:template name="display_heading">
<xsl:param name="text" />

	<table class="heading" cellspacing="0">
	<tr><td class="divider_left">&#160;&#160;</td>
	<td class="divider_middle" nowrap="">&#160;<xsl:value-of select="$text" />&#160;</td>
	<td class="divider_right" width="100%">&#160;</td></tr>
	</table>
	<br/>
</xsl:template>

</xsl:stylesheet>
