<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:template name="metadata_bottom_binary_files" />

<xsl:template name="metadata-binary-item">
<xsl:param name="position" />
<xsl:param name="node" />

  <xsl:call-template name="source_role">
    <xsl:with-param name="source_idx">
      <xsl:value-of select="$position" />
    </xsl:with-param>
  </xsl:call-template>
  <xsl:text>: </xsl:text>
	<xsl:choose>
	<xsl:when test="boolean($node) and $node/last-metadata/@deleted!='yes'">
		<xsl:choose>
		<xsl:when test="boolean($node/@title) and $node/@title != ''">
			<xsl:value-of select="$node/@title" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="$node/url" />
		</xsl:otherwise>
		</xsl:choose>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$kg_last_modified" />
    <xsl:text>: </xsl:text>
    <xsl:value-of select="$node/last-metadata/@modification-date" />
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$kg_size" />
    <xsl:text>: </xsl:text>
    <xsl:call-template name="display-size">
      <xsl:with-param name="size" select="$node/last-metadata/@size" />
    </xsl:call-template>
  </xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_missing_file" />
	</xsl:otherwise>
	</xsl:choose>
  <xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template match="statistics" mode="binary-files">

  <!-- title -->
  <xsl:choose>
  <xsl:when test="$g_is_stats_only">
    <xsl:value-of select="$kg_statistics_report_title" />
  </xsl:when>
  <xsl:otherwise>
    <xsl:call-template name="display_heading">
      <xsl:with-param name="text">
        <xsl:value-of select="$kg_statistics_title" />
      </xsl:with-param>
    </xsl:call-template>
  </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="$kg_linefeed" />

  <!-- details-->
  <xsl:call-template name="detailed_stats_for_binary_files" />
</xsl:template>

<xsl:template name="detailed_stats_for_binary_files">
  
  <xsl:choose>
  <xsl:when test="../@object-type='text-file'">
    <xsl:value-of select="$kg_statistics_detailed_one_binary_title" />
  </xsl:when>
  <xsl:otherwise>
    <xsl:value-of select="$kg_statistics_detailed_binary_title" />
  </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="$kg_linefeed" />

<!--
  <xsl:choose>
	<xsl:when test="pair/granularity[@type='files-binary']/@changed = 0">
		<xsl:value-of select="$kg_binary_files_identical" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_binary_files_different" />
	</xsl:otherwise>
	</xsl:choose>
-->
  <xsl:call-template name="statistics_details_binary" />
</xsl:template>

<xsl:template name="statistics_details_binary">

  <xsl:value-of select="$kg_all_changes" />
  <xsl:variable name="node_set" select="all/pair/granularity[@type='byteblocks' or @type='bytes']" />
  <xsl:choose>
    <xsl:when test="$g_is_3way_comparison">
      <xsl:value-of select="$kg_linefeed" />
      <xsl:call-template name="statistics_table_header">
        <xsl:with-param name="pair_nodes" select="all/pair" />
        <xsl:with-param name="stats_nodes_count" select="count(all/pair[1]/granularity[@type='byteblocks' or @type='bytes'])" />
        <xsl:with-param name="description_title">
          <xsl:value-of select="$kg_description" />
        </xsl:with-param>
        <xsl:with-param name="description_rowspan">2</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name="statistics_table_header_data_types">
        <xsl:with-param name="stats_nodes" select="$node_set" />
        <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="statistics_table_header_data_types">
        <xsl:with-param name="empty_left_cell">yes</xsl:with-param>
        <xsl:with-param name="empty_left_cell_colspan">2</xsl:with-param>
        <xsl:with-param name="stats_nodes" select="$node_set" />
        <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>

  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="$node_set" />
    <xsl:with-param name="attr_name">unchanged</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_unchanged_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="$node_set" />
    <xsl:with-param name="attr_name">inserted</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_inserted_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="$node_set" />
    <xsl:with-param name="attr_name">deleted</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_deleted_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
  </xsl:call-template>
<!--
  <xsl:if test="$g_can_ignore">
    <xsl:call-template name="statistics_data_line_per_diff_type">
      <xsl:with-param name="nodes" select="$node_set" />
      <xsl:with-param name="attr_name">ignored</xsl:with-param>
      <xsl:with-param name="rowspan">1</xsl:with-param>
      <xsl:with-param name="colspan">2</xsl:with-param>
      <xsl:with-param name="text1">
        <xsl:value-of select="$kg_ignored_items" />
      </xsl:with-param>
      <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
    </xsl:call-template>
  </xsl:if>
-->
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="$node_set" />
    <xsl:with-param name="attr_name">changed</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_changed_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,byteblocks,bytes,</xsl:with-param>
  </xsl:call-template>
</xsl:template>
  
</xsl:stylesheet>
