<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:param name="kg_columns">79</xsl:param>
<xsl:param name="kg_context">20</xsl:param>

<xsl:param name="kg_column_separator"><xsl:text> </xsl:text></xsl:param>

<xsl:variable name="g_spaces_line">
	<xsl:call-template name="make-string">
		<xsl:with-param name="length" select="number($kg_columns)" />
		<xsl:with-param name="text"><xsl:text> </xsl:text></xsl:with-param>
	</xsl:call-template>
</xsl:variable>

<xsl:template name="make-string">
<xsl:param name="length" />
<xsl:param name="text" />

<xsl:variable name="half-length" select="floor($length div 2)" />

<xsl:variable name="half">
	<xsl:if test="$half-length != 0">
		<xsl:call-template name="make-string">
			<xsl:with-param name="length" select="$half-length" />
			<xsl:with-param name="text" select="$text"/>
		</xsl:call-template>
	</xsl:if>
</xsl:variable>
<xsl:value-of select="$half" />
<xsl:value-of select="$half" />
<xsl:if test="($length mod 2) = 1 ">
	<xsl:value-of select="$text" />
</xsl:if>
</xsl:template>

<xsl:template name="compute_common_start">
<xsl:param name="ignore-empty">yes</xsl:param>
<xsl:param name="s1" />
<xsl:param name="s2" />

<xsl:choose>
<xsl:when test="$ignore-empty='yes' and $s1=''">
	<xsl:value-of select="$s2" />
</xsl:when>
<xsl:when test="$ignore-empty='yes' and $s2=''">
	<xsl:value-of select="$s1" />
</xsl:when>
<xsl:when test="$ignore-empty='no' and ($s1='' or $s2='')">
	<!-- nothing -->
</xsl:when>
<xsl:otherwise>
	<!-- basically we use a divide and conquer algo:
		check first half (rounding up) of s1 against start of the s2, 
			if equal, return this+common_start of remain (if any),
			if not, return common_start of the start
	-->
	<xsl:variable name="half" select="substring($s1, 1, ceiling(string-length($s1) div 2))" />
	<xsl:choose>
		<xsl:when test="starts-with($s2, $half)">
			<xsl:value-of select="$half" />
			<xsl:call-template name="compute_common_start">
				<xsl:with-param name="s1" select="substring($s1, 1 + string-length($half))" />
				<xsl:with-param name="s2" select="substring($s2, 1 + string-length($half))" />
				<xsl:with-param name="ignore-empty">no</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="compute_common_start">
				<xsl:with-param name="s1" select="substring($half, 1, string-length($half)-1)" />
				<xsl:with-param name="s2" select="$s2" />
				<xsl:with-param name="ignore-empty">no</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>	
</xsl:otherwise>
</xsl:choose>

</xsl:template>
<!--
We have two major presentation schemas:
- word-wrapped: all the lines are fully displayed, wrapped if necessary to a
	predetermined number of columns, in addition, the sub-parts of lines which
	are not identical are marked with some sign. the lines are presented inside
	two or three columns
	common lines are displayed as in truncated mode
- truncated: lines are displayed interleaved (L/[A/]/R) when they are not equal
	missing lines are not displayed at all, the other lines are marked with their
	state allowing the user to know what happens
	identical lines are prefixed with the two or three line numbers
	when changed lines (i.e. associated but content not equal), the first changed characters
	are presented (with a bit of context before)
	when not all the lines are equal, each line is prefixed by < for left, | for ancestor, > for right
-->

<xsl:param name="g_use_word_wrapping" select="/comparison-export/options/edition_options/@wrap_lines='yes'" />

<xsl:variable name="g_available_for_columns"><!-- space available once removed the separator character between columns -->
	<xsl:value-of select="$kg_columns - $g_sources_count + 1" />
</xsl:variable>

<xsl:variable name="g_available_columns_ancestor">
	<xsl:choose>
		<xsl:when test="$g_is_3way_comparison">
			<xsl:value-of select="floor($g_available_for_columns div 3)" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>0</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="g_available_columns_left">
	<xsl:value-of select="floor($g_available_for_columns div $g_sources_count)" />
</xsl:variable>

<xsl:variable name="g_available_columns_right">
	<xsl:value-of select="number($g_available_for_columns) - $g_available_columns_left - $g_available_columns_ancestor" />
</xsl:variable>

<xsl:variable name="g_use_inline_diff">
	<xsl:variable name="text_diff_options" select="/comparison-export/options/file_comparison_options" />
	<xsl:if test="$text_diff_options/@word_level='yes' or $text_diff_options/@char_level='yes'">yes</xsl:if>
</xsl:variable>

<xsl:variable name="g_unify_identical_lines">yes</xsl:variable><!-- it's so practical with 'yes'... select="/comparison-export/options/reports_options/text_files_options/@identical_parts_as_single_column" />-->

<xsl:template name="metadata_bottom_text" />

<xsl:template name="metadata-text-item">
<xsl:param name="position" />
<xsl:param name="node" />

<xsl:variable name="content-info-node" select="$node/../../content-info/*[name() = name($node)]" />

	<xsl:call-template name="source_role">
		<xsl:with-param name="source_idx"><xsl:value-of select="$position" /></xsl:with-param>
	</xsl:call-template>
	<xsl:text>: </xsl:text>
	<xsl:choose>
	<xsl:when test="boolean($node) and $node/last-metadata/@deleted!='yes'">
		<xsl:choose>
		<xsl:when test="boolean($node/@title) and $node/@title != ''">
			<xsl:value-of select="$node/@title" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="$node/url" />
		</xsl:otherwise>
		</xsl:choose>
		<xsl:text>, </xsl:text>
		<xsl:value-of select="$kg_last_modified" />
    <xsl:text>: </xsl:text>
		<xsl:value-of select="$node/last-metadata/@modification-date" />
    <xsl:text>, </xsl:text>
		<xsl:value-of select="$kg_size" />
    <xsl:text>: </xsl:text>
		<xsl:call-template name="display-size">
			<xsl:with-param name="size" select="$node/last-metadata/@size" />
		</xsl:call-template>
		<xsl:text> (</xsl:text>
		<xsl:value-of select="$content-info-node/@lines-count" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="$kg_lines" />
		<xsl:text>)</xsl:text>
		<xsl:text>, </xsl:text>
		<xsl:value-of select="$kg_encoding" /><xsl:text>: </xsl:text>
		<xsl:value-of select="$content-info-node/@encoding" />
		<xsl:text> </xsl:text>
		<xsl:choose>
		<xsl:when test="$content-info-node/@encoding-origin='detected'">
			<xsl:value-of select="$kg_encoding_autodetected" />
		</xsl:when>
		<xsl:when test="$content-info-node/@encoding-origin='default'">
			<xsl:value-of select="$kg_encoding_default" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$kg_encoding_forced" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_missing_file" />
	</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template match="details" mode="text-files">

	<xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_details_title" />
		</xsl:with-param>
	</xsl:call-template>
  <xsl:value-of select="$kg_linefeed" />
  <xsl:apply-templates mode="text-files" />
</xsl:template>

<xsl:template match="details/line" mode="text-files">

	<xsl:choose>
	<xsl:when test="boolean(@skipped)">
		<xsl:call-template name="output-skipped-line" />
	</xsl:when>
	<xsl:when test="$g_unify_identical_lines='yes' and not (@conflict-middle) and count(source[@class='UU'])=$g_sources_count">
		<xsl:call-template name="output-unified-line" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:choose>
		<xsl:when test="$g_use_word_wrapping">
			<!-- we must handle the 2/3 lines as a single block -->
			<xsl:value-of select="$kg_column_separator" />
			<xsl:value-of select="$kg_linefeed" />
		</xsl:when>
		<xsl:otherwise>
			<!-- we want to study all available lines and extract from them an interesting part,
				this part should contain changes, for changed lines -->
			<xsl:variable name="left_line_text">
				<xsl:apply-templates select="source[@role=1]/*" />
			</xsl:variable>
			<xsl:variable name="right_line_text">
				<xsl:apply-templates select="source[@role=2]/*" />
			</xsl:variable>
			<xsl:variable name="ancestor_line_text">
				<xsl:apply-templates select="source[@role=0]/*" />
			</xsl:variable>

			<xsl:variable name="common_text_lr">
				<xsl:call-template name="compute_common_start">
					<xsl:with-param name="ignore-empty">yes</xsl:with-param>
					<xsl:with-param name="s1" select="$left_line_text" />
					<xsl:with-param name="s2" select="$right_line_text" />
				</xsl:call-template>
			</xsl:variable>

			<xsl:variable name="common_text">
				<xsl:call-template name="compute_common_start">
					<xsl:with-param name="ignore-empty">yes</xsl:with-param>
					<xsl:with-param name="s1" select="$common_text_lr" />
					<xsl:with-param name="s2" select="$ancestor_line_text" />
				</xsl:call-template>
			</xsl:variable>
			
			<!-- basically, we want to show a part of the line which is
					interesting to the user, that is: a part containing at least some modifications -->
			<xsl:variable name="start_at">
				<xsl:choose>
					<xsl:when test="($common_text=$left_line_text or $left_line_text='') and ($common_text=$ancestor_line_text or $ancestor_line_text='') and  ($common_text=$right_line_text or $right_line_text='')">
							<xsl:text>0</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="(0 &lt; (string-length($common_text) - $kg_context)) * (string-length($common_text) - $kg_context)" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<xsl:apply-templates select="source[@role=1]" mode="text-files">
				<xsl:with-param name="left" select="@conflict-middle" />
				<xsl:with-param name="available_columns" select="$kg_columns" />
				<xsl:with-param name="start_at" select="$start_at" />
			</xsl:apply-templates>
			<xsl:if test="$g_is_3way_comparison">
				<xsl:apply-templates select="source[@role=0]" mode="text-files">
					<xsl:with-param name="available_columns" select="$kg_columns" />
					<xsl:with-param name="start_at" select="$start_at" />
				</xsl:apply-templates>
			</xsl:if>
			
			<xsl:apply-templates select="source[@role=2]" mode="text-files">
				<xsl:with-param name="right" select="@conflict-middle" />
				<xsl:with-param name="available_columns" select="$kg_columns" />
				<xsl:with-param name="start_at" select="$start_at" />
			</xsl:apply-templates>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="single-cell-line-attrs">
</xsl:template>

<xsl:template name="output-unified-line"> <!-- used for 'simple equality' lines -->

	<xsl:variable name="line_number_text">
		<xsl:for-each select="source[@role=1]">
			<xsl:call-template name="output-line_number">
				<xsl:with-param name="top">no</xsl:with-param>
				<xsl:with-param name="bottom">no</xsl:with-param>
			</xsl:call-template>
			<xsl:text>-</xsl:text>
		</xsl:for-each>
		<xsl:for-each select="source[@role=0]">
			<xsl:call-template name="output-line_number">
				<xsl:with-param name="top">no</xsl:with-param>
				<xsl:with-param name="bottom">no</xsl:with-param>
			</xsl:call-template>
			<xsl:text>-</xsl:text>
		</xsl:for-each>
		<xsl:for-each select="source[@role=2]">
			<xsl:call-template name="output-line_number">
				<xsl:with-param name="top">no</xsl:with-param>
				<xsl:with-param name="bottom">no</xsl:with-param>
			</xsl:call-template>
		</xsl:for-each>
	<xsl:text> </xsl:text>
	</xsl:variable>
	
	<xsl:value-of select="$line_number_text" />
	
	<xsl:variable name="line-text">
		<xsl:apply-templates select="source[@role=1]/*" />
	</xsl:variable>
	<xsl:call-template name="output-line-span">
		<xsl:with-param name="available_columns_first_line" select="$kg_columns - string-length($line_number_text)" />
		<xsl:with-param name="available_columns" select="$kg_columns" />
		<xsl:with-param name="line_text" select="$line-text" />
	</xsl:call-template>
	<xsl:if test="$g_use_word_wrapping">
		<xsl:call-template name="output-line-tail">
			<xsl:with-param name="order" select="1" />
			<xsl:with-param name="available_columns_first_line" select="$kg_columns - string-length($line_number_text)" />
			<xsl:with-param name="available_columns" select="$kg_columns" />
			<xsl:with-param name="line_text" select="$line-text" />
		</xsl:call-template>
	</xsl:if>
	<xsl:value-of select="$kg_linefeed" />
	
</xsl:template>

<xsl:template name="output-skipped-line">

	<xsl:choose>
	<xsl:when test="$g_show_skipped_lines">
		<xsl:text>---</xsl:text>
		<xsl:call-template name="kg_skipped_lines">
			<xsl:with-param name="nb" select="@skipped" />
		</xsl:call-template>
		<xsl:text>---</xsl:text>
	</xsl:when>
	</xsl:choose>
	<xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template name="conflict-border">
<xsl:param name="left" />
<xsl:param name="right" />
<xsl:param name="top" />
<xsl:param name="bottom" />

</xsl:template>

<xsl:template name="output-line-span">
<xsl:param name="order" select="0" />
<xsl:param name="available_columns_first_line" />
<xsl:param name="available_columns" />
<xsl:param name="line_text" />

<xsl:variable name="available-length">
	<xsl:choose>
		<xsl:when test="number(order) &gt; 0">
			<xsl:value-of select="$available_columns" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$available_columns_first_line" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="available-text">
	<xsl:choose>
		<xsl:when test="number(order) &gt; 0">
			<xsl:value-of select="substring($line_text, 1 + number($available_columns_first_line) + (number($order)-1)*number($available_columns), $available-length)" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="substring($line_text, 1, $available-length)" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:value-of select="$available-text" />
<!-- do pad with spaces what was not used by true text -->
<xsl:value-of select="substring($g_spaces_line, 1, number($available-length) - string-length($available-text))" />
</xsl:template>

<xsl:template name="output-line-tail">
<xsl:param name="available_columns" />
<xsl:param name="line_text" />

<xsl:if test="$line_text != ''">
	<xsl:variable name="available-text">
		<xsl:value-of select="substring($line_text, 1, number($available_columns))" />
	</xsl:variable>
	<xsl:value-of select="$available-text" />
	<xsl:value-of select="substring($g_spaces_line, 1, number($available_columns) - string-length($available-text))" />

	<xsl:call-template name="output-line-tail">
		<xsl:with-param name="available_columns" select="$available_columns" />
		<xsl:with-param name="line_text" select="substring($line_text, 1 + number($available_columns))" />
	</xsl:call-template>
	<xsl:value-of select="$kg_linefeed" />
</xsl:if>

</xsl:template>

<xsl:template match="details/line/source" mode="text-files">
<xsl:param name="left" />
<xsl:param name="right" />
<xsl:param name="available_columns" />
<xsl:param name="start_at">0</xsl:param>

	<xsl:choose>
	<xsl:when test="$g_use_word_wrapping">
	</xsl:when>
	<xsl:otherwise>
		<xsl:if test="not (@empty='yes')" >
			<!-- truncated mode: omit empty lines, handle them in L/A/R (suffix the line number), do something like 123< A , 42| R, or 1> C -->
			
			<!--<xsl:call-template -->

			<xsl:variable name="line_number_text">
				<xsl:call-template name="output-line_number">
					<xsl:with-param name="top">no</xsl:with-param>
					<xsl:with-param name="bottom">no</xsl:with-param>
				</xsl:call-template>
				
				<xsl:choose>
				<xsl:when test="@role='1'"><xsl:text>&lt;</xsl:text></xsl:when>
				<xsl:when test="@role='0'"><xsl:text>|</xsl:text></xsl:when>
				<xsl:when test="@role='2'"><xsl:text>&gt;</xsl:text></xsl:when>
				</xsl:choose>

				<xsl:call-template name="output-class-code">
					<xsl:with-param name="class" select="@class" />
				</xsl:call-template>
				
				<xsl:text> </xsl:text>
				<xsl:if test="$start_at!=0">
					<xsl:text>[...]</xsl:text>
				</xsl:if>
			</xsl:variable>
			
			<xsl:value-of select="$line_number_text" />
			
			<xsl:variable name="line-text">
				<xsl:apply-templates />
			</xsl:variable>
			<xsl:call-template name="output-line-span">
				<xsl:with-param name="available_columns_first_line" select="$available_columns - string-length($line_number_text)" />
				<xsl:with-param name="available_columns" select="$available_columns" />
				<xsl:with-param name="line_text" select="substring($line-text, $start_at+1)" />
			</xsl:call-template>
			<xsl:value-of select="$kg_linefeed" />
		</xsl:if>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="span">

	<xsl:variable name="class_attr">
		<xsl:call-template name="span_attr_action" />
		<xsl:call-template name="span_attr_syntax" />
	</xsl:variable>
	
	<xsl:choose>
	<xsl:when test="$class_attr = ''">
		<xsl:apply-templates />
	</xsl:when>
	<xsl:otherwise>
		<span class="{normalize-space($class_attr)}">
			<xsl:apply-templates />
		</span>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="span_action" />
<xsl:template name="span_syntax" />

<xsl:template name="span_attr_action">

	<xsl:if test="boolean(@class)">
		<xsl:choose>
		<xsl:when test="$g_use_inline_diff and $g_use_monochrome_css">
			<xsl:text>inline_</xsl:text><xsl:value-of select="@class" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="@class" />
		</xsl:otherwise>
		</xsl:choose>
		<xsl:text> </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="span_attr_syntax">
<xsl:variable name="current_report_node" select="ancestor::comparison-export" />
<xsl:variable name="style_node" select="$current_report_node/options/styles" />
<xsl:variable name="lexer" select="$style_node/@language" />

	<xsl:text>S</xsl:text><xsl:value-of select="$lexer" /><xsl:value-of select="@style" /><xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="s">

	<xsl:text>&#160;</xsl:text>
<!--
	<xsl:choose>
	<xsl:when test="/comparison-export/options/display_options/@display_white_spaces='yes'">
		<small>&#8201;&#183;&#8201;</small>
	</xsl:when>
	<xsl:otherwise>
		<xsl:text> </xsl:text>
	</xsl:otherwise>
	</xsl:choose>
-->
</xsl:template>

<xsl:template match="t">

	<xsl:call-template name="output_tab">
		<xsl:with-param name="count"><xsl:value-of select="@width" /></xsl:with-param>
	</xsl:call-template>
<!--
	<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
	<xsl:choose>
	<xsl:when test="/comparison-export/options/display_options/@display_white_spaces='yes'">
		<small>&#8201;&#187;&#8201;</small>
	</xsl:when>
	<xsl:otherwise>
		<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
	</xsl:otherwise>
	</xsl:choose>
-->
</xsl:template>

<xsl:template name="output_tab">
<xsl:param name="count" />

	<xsl:if test="number($count) &gt; 0">
		<xsl:text>&#160;</xsl:text>
		<xsl:call-template name="output_tab">
			<xsl:with-param name="count">
				<xsl:value-of select="number($count - 1)" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="cr">

	<xsl:if test="/comparison-export/options/display_options/@display_line_endings='yes'">
		<xsl:call-template name="control_char">
			<xsl:with-param name="text">CR</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="lf">

	<xsl:if test="/comparison-export/options/display_options/@display_line_endings='yes'">
		<xsl:call-template name="control_char">
			<xsl:with-param name="text">LF</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="brk">
	<wbr/>
</xsl:template>

<xsl:template match="cc">

	<xsl:call-template name="control_char">
		<xsl:with-param name="text"><xsl:value-of select="@name"/></xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="control_char">
<xsl:param name="text" />

		<small>
			<span class="line_ending">
				<xsl:attribute name="style">
					<xsl:text>color: </xsl:text>
					<xsl:call-template name="control_char_colour" />
				</xsl:attribute>
				<xsl:value-of select="$text" />
			</span>
			<xsl:text> </xsl:text>
		</small>
</xsl:template>

<xsl:template name="control_char_colour">

	<xsl:choose>
	<xsl:when test="$g_use_external_css or $g_use_coloured_css">
		<xsl:variable name="display-options" select="/comparison-export/options/display_options" />
		<xsl:variable name="current-class" select="translate(../@class, 'ACIRU', 'aciru')" />
		<xsl:variable name="color-node" select="$display-options/@*[name()=concat($current-class, '_text_bgcolor')]" />
	
		<xsl:choose>
		<xsl:when test="boolean($color-node)">
			<xsl:value-of select="$color-node"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>FFFFFF</xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:text>FFFFFF</xsl:text>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="output-line_number">

	<xsl:choose>
	<xsl:when test="@line_number &gt;= 0">
		<xsl:value-of select="@line_number + 1" />
	</xsl:when>
	<xsl:otherwise>
		<!--<xsl:text>&#160;</xsl:text>-->
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="statistics" mode="text-files">

	<!-- title -->
	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
		<xsl:value-of select="$kg_statistics_report_title" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_statistics_title" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:otherwise>
	</xsl:choose>
  <xsl:value-of select="$kg_linefeed" />
	
	<!-- data table -->
	<xsl:call-template name="detailed_stats_for_text_files" />
</xsl:template>

<xsl:template name="detailed_stats_for_text_files">

	<xsl:choose>
	<xsl:when test="../@object-type='text-file'">
		<xsl:value-of select="$kg_statistics_detailed_one_text_title" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_statistics_detailed_text_title" />
	</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$kg_linefeed" />
	
	<xsl:call-template name="statistics_details_text" />
  <xsl:value-of select="$kg_linefeed" />
  
	<xsl:if test="$g_is_3way_comparison">
		<!-- conflicts -->
		<xsl:call-template name="statistics_conflicts" />
	</xsl:if>
  
</xsl:template>

<xsl:template name="statistics_details_text">
	
	<xsl:value-of select="$kg_all_changes" />
	<xsl:variable name="node_set" select="all/pair/granularity[@type='blocks' or @type='lines']" />
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
    <xsl:value-of select="$kg_linefeed" />
		<xsl:call-template name="statistics_table_header">
			<xsl:with-param name="pair_nodes" select="all/pair" />
			<xsl:with-param name="stats_nodes_count" select="count(all/pair[1]/granularity[@type='blocks' or @type='lines'])" />
			<xsl:with-param name="description_title"><xsl:value-of select="$kg_description" /></xsl:with-param>
			<xsl:with-param name="description_rowspan">2</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_table_header_data_types">
			<xsl:with-param name="stats_nodes" select="$node_set" />
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="statistics_table_header_data_types">
			<xsl:with-param name="empty_left_cell">yes</xsl:with-param>
			<xsl:with-param name="empty_left_cell_colspan">2</xsl:with-param>
			<xsl:with-param name="stats_nodes" select="$node_set" />
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
	</xsl:otherwise>
	</xsl:choose>

	<xsl:call-template name="statistics_data_line_per_diff_type">
		<xsl:with-param name="nodes" select="$node_set" />
		<xsl:with-param name="attr_name">unchanged</xsl:with-param>
		<xsl:with-param name="rowspan">1</xsl:with-param>
		<xsl:with-param name="colspan">2</xsl:with-param>
		<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
		<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
	</xsl:call-template>
	<xsl:call-template name="statistics_data_line_per_diff_type">
		<xsl:with-param name="nodes" select="$node_set" />
		<xsl:with-param name="attr_name">inserted</xsl:with-param>
		<xsl:with-param name="rowspan">1</xsl:with-param>
		<xsl:with-param name="colspan">2</xsl:with-param>
		<xsl:with-param name="text1"><xsl:value-of select="$kg_inserted_items" /></xsl:with-param>
		<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
	</xsl:call-template>
	<xsl:call-template name="statistics_data_line_per_diff_type">
		<xsl:with-param name="nodes" select="$node_set" />
		<xsl:with-param name="attr_name">deleted</xsl:with-param>
		<xsl:with-param name="rowspan">1</xsl:with-param>
		<xsl:with-param name="colspan">2</xsl:with-param>
		<xsl:with-param name="text1"><xsl:value-of select="$kg_deleted_items" /></xsl:with-param>
		<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
	</xsl:call-template>
	<xsl:if test="$g_can_ignore">
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="$node_set" />
			<xsl:with-param name="attr_name">ignored</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_ignored_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
	<xsl:call-template name="statistics_data_line_per_diff_type">
		<xsl:with-param name="nodes" select="$node_set" />
		<xsl:with-param name="attr_name">changed</xsl:with-param>
		<xsl:with-param name="rowspan">1</xsl:with-param>
		<xsl:with-param name="colspan">2</xsl:with-param>
		<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
		<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template name="statistics_conflicts_details_text">

	<xsl:if test="all/granularity[@type!='files']/@conflict &gt; 0">
		<xsl:call-template name="kg_merge_files_conflicts_description">
			<xsl:with-param name="nb" select="all/granularity[@type!='files']/@conflict" />
		</xsl:call-template>

    <xsl:call-template name="statistics_table_header">
			<xsl:with-param name="pair_nodes" select="conflicts/*[name()!='granularity']" />
			<xsl:with-param name="stats_nodes_count" select="count(conflicts[1]/*[1]/granularity[@type='blocks' or @type='lines'])" />
			<xsl:with-param name="description_title"><xsl:value-of select="$kg_description" /></xsl:with-param>
			<xsl:with-param name="description_rowspan">2</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_table_header_data_types">
			<xsl:with-param name="stats_nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
			
		<xsl:call-template name="statistics_conflicts_details_text_lines" />

		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
			<xsl:with-param name="attr_name">unchanged</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_unchanged_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
			<xsl:with-param name="attr_name">inserted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_inserted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
			<xsl:with-param name="attr_name">deleted</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_deleted_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
		<xsl:if test="$g_can_ignore">
			<xsl:call-template name="statistics_data_line_per_diff_type">
				<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
				<xsl:with-param name="attr_name">ignored</xsl:with-param>
				<xsl:with-param name="rowspan">1</xsl:with-param>
				<xsl:with-param name="colspan">2</xsl:with-param>
				<xsl:with-param name="text1"><xsl:value-of select="$kg_ignored_items" /></xsl:with-param>
				<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
				<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="statistics_data_line_per_diff_type">
			<xsl:with-param name="nodes" select="conflicts/*/granularity[@type='blocks' or @type='lines']" />
			<xsl:with-param name="attr_name">changed</xsl:with-param>
			<xsl:with-param name="rowspan">1</xsl:with-param>
			<xsl:with-param name="colspan">2</xsl:with-param>
			<xsl:with-param name="text1"><xsl:value-of select="$kg_changed_items" /></xsl:with-param>
			<xsl:with-param name="types_subset">,blocks,lines,</xsl:with-param>
			<xsl:with-param name="empty_col_before_01">no</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template name="statistics_conflicts_details_text_lines">
</xsl:template>

</xsl:stylesheet>
