﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:variable name="g_is_for_merge" select="contains($g_gui_type, 'merge')" />
<xsl:variable name="g_is_merge_with_output" select="/comparison-export/@output-defined='yes'" />
<xsl:variable name="g_show_changes_count" select="$g_folder_display_options_node/@show_diffcount='yes'" />
<xsl:variable name="g_show_changes_count_in_left" select="$g_show_changes_count" />
<xsl:variable name="g_show_changes_count_in_non_left" select="$g_is_3way_comparison and $g_show_changes_count" />
<xsl:variable name="g_indent_non_left_trees" select="$g_folder_display_options_node/@indent_non_left_trees='yes'" />

<xsl:variable name="g_folder_column_width_number">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:choose>
		<xsl:when test="$g_is_for_merge">
			<xsl:choose>
			<xsl:when test="$g_is_merge_with_output">20</xsl:when>
			<xsl:otherwise>25</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>33</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:choose>
		<xsl:when test="$g_is_for_merge">
			<xsl:choose>
			<xsl:when test="$g_is_merge_with_output">25</xsl:when>
			<xsl:otherwise>33</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>50</xsl:otherwise>
		</xsl:choose>
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="g_folder_column_width">
	<xsl:value-of select="$g_folder_column_width_number" /><xsl:text>%</xsl:text>
</xsl:variable>

<xsl:template name="metadata_bottom_folders">

	<xsl:if test="$g_is_for_merge and not($g_is_merge_with_output) and boolean(/comparison-export/details)">
		<xsl:value-of select="$kg_no_result_location" />
	</xsl:if>
</xsl:template>

<xsl:template name="metadata-folder-item">
<xsl:param name="position" />
<xsl:param name="node" />

	<xsl:call-template name="source_role">
		<xsl:with-param name="source_idx"><xsl:value-of select="$position" /></xsl:with-param>
	</xsl:call-template>
	<xsl:text>: </xsl:text>
	<xsl:choose>
	<xsl:when test="boolean($node)">
		<xsl:choose>
		<xsl:when test="boolean($node/@title) and $node/@title != ''">
			<xsl:value-of select="$node/@title" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="$node/url" />
		</xsl:otherwise>
		</xsl:choose>
		<xsl:text>, </xsl:text>
		<xsl:value-of select="$kg_encoding" />
		<xsl:text>: </xsl:text>
		<xsl:choose>
		<xsl:when test="boolean($node/@prefered-ansi-encoding)">
			<xsl:value-of select="$node/@prefered-ansi-encoding" />
		</xsl:when>
		<xsl:when test="boolean($node/loading-encoding-props/@encoding)">
			<xsl:value-of select="$node/loading-encoding-props/@encoding" />
		</xsl:when>
		</xsl:choose>
    
    <xsl:text> </xsl:text>
		<xsl:choose>
		<xsl:when test="$node/loading-encoding-props/@use_signature='yes'">
			<xsl:value-of select="$kg_encoding_default" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$kg_encoding_forced" />
		</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="$g_is_for_merge and $g_is_merge_with_output">
			<xsl:text>, </xsl:text>
			<xsl:value-of select="$kg_result_location" />
			<xsl:text>: </xsl:text>
			<xsl:call-template name="output-yes-no">
				<xsl:with-param name="text" select="$node/@output" />
			</xsl:call-template>
		</xsl:if>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_missing_folder" />
	</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template match="details" mode="folders">

  <xsl:call-template name="display_heading">
		<xsl:with-param name="text">
			<xsl:value-of select="$kg_details_title" />
		</xsl:with-param>
	</xsl:call-template>
  <xsl:value-of select="$kg_linefeed" />
  
	<xsl:value-of select="$kg_relative_path" />
	<xsl:text>, </xsl:text><xsl:value-of select="$kg_presence" />
	<xsl:if test="$g_show_changes_count">
		<xsl:text>, </xsl:text><xsl:call-template name="kg_changes" />
	</xsl:if>
	
	<xsl:if test="$g_is_for_merge">
		<xsl:text>, </xsl:text><xsl:value-of select="$kg_merge_result" />
		<xsl:if test="$g_is_merge_with_output">
			<xsl:text>, </xsl:text><xsl:value-of select="$kg_action" />
		</xsl:if>
	</xsl:if>
	<xsl:value-of select="$kg_linefeed" />

	<!-- table content -->
	<xsl:apply-templates mode="folders" />
</xsl:template>

<xsl:template name="state_sign">
<xsl:param name="node" />

	<xsl:for-each select="$node"><xsl:call-template name="item_bgcolor_text" /></xsl:for-each>
</xsl:template>

<xsl:template name="output-name-spacing">

	<xsl:text>   </xsl:text>
</xsl:template>

<xsl:template match="item[parent::details or parent::item]" mode="folders">

	<xsl:if test="count(*[@deleted='yes'])!=$g_sources_count">
		<!-- we take the first name out of left/ancestor/right/result -->
		<xsl:for-each select="(left|right|ancestor|result)[@deleted!='yes'][position()=1]" >
			<xsl:variable name="actual_name">
				<xsl:call-template name="file_name" />
				<xsl:if test="@is-folder='yes'">
					<xsl:text>/</xsl:text>
				</xsl:if>
			</xsl:variable>
			
			<xsl:value-of select="$actual_name" />
			<xsl:call-template name="output-name-spacing">
				<xsl:with-param name="filled" select="string-length($actual_name)" />
			</xsl:call-template>
		</xsl:for-each>
		
		<!-- display the state for eahc file -->
		<xsl:call-template name="state_sign"><xsl:with-param name="node" select="left"/></xsl:call-template>
		<xsl:if test="$g_is_3way_comparison">
			<xsl:call-template name="state_sign"><xsl:with-param name="node" select="ancestor"/></xsl:call-template>
		</xsl:if>
		<xsl:call-template name="state_sign"><xsl:with-param name="node" select="right"/></xsl:call-template>

		<!-- now output the changes counts as: LR or LA/AR/LR -->
    <xsl:if test="$g_show_changes_count">
  		<xsl:text>, </xsl:text>
		  <xsl:value-of select="left/@diff-count" />
		  <xsl:if test="$g_is_3way_comparison">
			  <xsl:text>/</xsl:text>
			  <xsl:value-of select="ancestor/@diff-count" />
			  <xsl:text>/</xsl:text>
			  <xsl:value-of select="right/@diff-count" />
		  </xsl:if>
     </xsl:if>
		
		<xsl:if test="$g_is_for_merge">
			<xsl:text>, </xsl:text>
			<xsl:call-template name="item_extra_text">
				<xsl:with-param name="text" select="./@result" />
			</xsl:call-template>
			<xsl:if test="$g_is_merge_with_output">
				<xsl:text>, </xsl:text>
				<xsl:call-template name="item_extra_text">
					<xsl:with-param name="text" select="./@actions" />
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:value-of select="$kg_linefeed" />

		<xsl:apply-templates select="item" mode="folders" />
	</xsl:if>
</xsl:template>

<xsl:template name="item_extra_text">
<xsl:param name="text" />

	<xsl:choose>
	<xsl:when test="@conflict='unresolved'">
		<xsl:if test="not($g_use_monochrome_css)">
			<xsl:attribute name="class">conflict</xsl:attribute>
		</xsl:if>
		<xsl:value-of select="$text" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$text" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="file_name">

	<xsl:choose>
	<xsl:when test="boolean (../@sub-report)">
		<a href="{../@sub-report}">
			<xsl:value-of select="@filename" />
		</a>
	</xsl:when>
	<xsl:when test="boolean (../@sub-report-id)">
		<a href="#{../@sub-report-id}">
			<xsl:value-of select="@filename" />
		</a>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="@filename" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="item_bgcolor_text">

	<xsl:choose>
	<xsl:when test="../@visible='no'">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">IU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="./@deleted='yes'">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">RU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="not(boolean(@status))">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">UU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="@status='always'">
		<xsl:text>UNKNOWN ITEM STATUS always</xsl:text>
	</xsl:when>
	<xsl:when test="@status='added'">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">AU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="@status='missing'">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">RU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:when test="@status='difference'">
		<xsl:call-template name="output-class-code">
			<xsl:with-param name="class">CU</xsl:with-param>
		</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
		<xsl:text>UNKNOWN ITEM STATUS </xsl:text><xsl:value-of select="@status" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="item_bgcolor_classname">

	<xsl:choose>
	<xsl:when test="../@visible='no'">
		<xsl:text>I </xsl:text>
	</xsl:when>
	<xsl:when test="./@deleted='yes'">
		<xsl:text>R </xsl:text>
	</xsl:when>
	<xsl:when test="not(boolean(@status))">
		<xsl:text>U </xsl:text>
	</xsl:when>
	<xsl:when test="@status='always'">
<!--
		<xsl:text>UNKNOWN ITEM STATUS always</xsl:text>
-->
	</xsl:when>
	<xsl:when test="@status='added'">
		<xsl:text>A </xsl:text>
	</xsl:when>
	<xsl:when test="@status='missing'">
		<xsl:text>R </xsl:text>
	</xsl:when>
	<xsl:when test="@status='difference'">
		<xsl:text>C </xsl:text>
	</xsl:when>
	<xsl:otherwise>
<!--
		<xsl:text>UNKNOWN ITEM STATUS </xsl:text><xsl:value-of select="@status" />
-->
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="statistics" mode="folders">

	<!-- title -->
	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
		<xsl:value-of select="$kg_statistics_report_title" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_statistics_title" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:otherwise>
	</xsl:choose>
  <xsl:value-of select="$kg_linefeed" />
	
	<!-- global data table -->
	<xsl:if test="../@object-type='folder'">
		<xsl:apply-templates select="all" />
	</xsl:if>
  <xsl:value-of select="$kg_linefeed" />
	
	<!-- detailed data tables per document type -->
	<xsl:if test="sum(all/pair/granularity[@type='files-text']/@changed) + sum(all/pair/granularity[@type='files-text']/@unchanged) &gt; 0">
		<xsl:call-template name="detailed_stats_for_text_files" />
    <xsl:value-of select="$kg_linefeed" />
	</xsl:if>
	<xsl:if test="sum(all/pair/granularity[@type='files-image']/@changed) + sum(all/pair/granularity[@type='files-image']/@unchanged) &gt; 0">
		<xsl:call-template name="detailed_stats_for_image_files" />
    <xsl:value-of select="$kg_linefeed" />
	</xsl:if>
	<xsl:if test="sum(all/pair/granularity[@type='files-binary']/@changed) + sum(all/pair/granularity[@type='files-binary']/@unchanged) &gt; 0">
		<xsl:call-template name="detailed_stats_for_binary_files" />
    <xsl:value-of select="$kg_linefeed" />
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
