﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
xmlns:xlink="http://www.w3.org/1999/xlink">

<xsl:output method="text" encoding="utf-8"/>

<!-- per-document report stylesheet -->
<xsl:include href="text-report-files.xsl" />
<xsl:include href="text-report-images.xsl" />
<xsl:include href="text-report-binary-files.xsl" />
<xsl:include href="text-report-eqtest-files.xsl" />
<xsl:include href="text-report-folders.xsl" />
<!-- common templates -->
<xsl:include href="all-reports-common.xsl" />

<!-- main section -->
<xsl:template match="/">

	<!-- report title -->
	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
		<xsl:value-of select="$kg_statistics_report_title" />
	</xsl:when>
	<xsl:when test="boolean(/comparison-export/@title)">
		<xsl:value-of select="/comparison-export/@title" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_report_title" />
	</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$kg_linefeed" />
  <xsl:value-of select="$kg_linefeed" />

	<!-- main section of the report -->
	<xsl:apply-templates select="/comparison-export" />
	
	<!-- for embedded files reports in folders reports -->
	<xsl:apply-templates select="/comparison-export/sub-reports" />

	<!-- footer -->
	<xsl:if test="not($g_top_level_comparison_type='binary-file' or $g_top_level_comparison_type='eqtest-file')">
		<xsl:call-template name="legend" />
	</xsl:if>
  <xsl:call-template name="kg_report_info" >
  	<xsl:with-param name="date" select="/comparison-export/@date" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="comparison-export">

	<!-- title for sub-reports -->
	<xsl:if test="count(ancestor::*)&gt;0">
		<xsl:call-template name="display_heading">
			<xsl:with-param name="text">
				<xsl:value-of select="$kg_sub_report_title" />
			</xsl:with-param>
		</xsl:call-template>
    <xsl:value-of select="$kg_linefeed" />
  </xsl:if>
	<xsl:apply-templates select="metadata" />
	
	<xsl:apply-templates select="statistics" />
  <xsl:value-of select="$kg_linefeed" />
  
	<xsl:apply-templates select="details" />
  <xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template match="metadata">

	<xsl:choose>
	<xsl:when test="$g_is_stats_only">
	<!-- no metadata in statistics only reports -->
	</xsl:when>
	<xsl:otherwise>
		<!-- section title -->
		<xsl:call-template name="metadata-title" />
		
		<!-- left source -->
		<xsl:call-template name="metadata_source">
			<xsl:with-param name="node" select="left" />
			<xsl:with-param name="position" select="1" />
		</xsl:call-template>
		<!-- right source -->
		<xsl:call-template name="metadata_source">
			<xsl:with-param name="node" select="right" />
			<xsl:with-param name="position" select="2" />
		</xsl:call-template>
		<xsl:if test="$g_is_3way_comparison">
			<!-- ancestor source -->
			<xsl:call-template name="metadata_source">
				<xsl:with-param name="node" select="ancestor" />
				<xsl:with-param name="position" select="0" />
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="metadata_bottom" />
	</xsl:otherwise>
	</xsl:choose>
  <xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template match="statistics/all">

  <xsl:value-of select="$kg_statistics_global_title" />
  <xsl:value-of select="$kg_linefeed" />

  <xsl:call-template name="statistics_table_header">
    <xsl:with-param name="pair_nodes" select="pair" />
    <xsl:with-param name="stats_nodes_count">0</xsl:with-param>
    <xsl:with-param name="description_title">
      <xsl:value-of select="$kg_files_and_folders" />
    </xsl:with-param>
    <xsl:with-param name="description_rowspan">1</xsl:with-param>
  </xsl:call-template>

  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
    <xsl:with-param name="attr_name">unchanged</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_unchanged_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
    <xsl:with-param name="attr_name">inserted</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_inserted_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
    <xsl:with-param name="attr_name">deleted</xsl:with-param>
    <xsl:with-param name="rowspan">1</xsl:with-param>
    <xsl:with-param name="colspan">2</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_deleted_items" />
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files,</xsl:with-param>
  </xsl:call-template>

  <!-- changed files -->
  <xsl:variable name="file_types" select="count(pair[1]/granularity[starts-with(@type, 'files-')])" />
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files']" />
    <xsl:with-param name="attr_name">changed</xsl:with-param>
    <xsl:with-param name="rowspan">
      <xsl:value-of select="number($file_types) + 1" />
    </xsl:with-param>
    <!-- computed from the number of handled file types -->
    <xsl:with-param name="colspan">1</xsl:with-param>
    <xsl:with-param name="text1">
      <xsl:value-of select="$kg_changed_items" />
    </xsl:with-param>
    <xsl:with-param name="text2"><xsl:value-of select="$kg_all_files" />*</xsl:with-param>
    <xsl:with-param name="types_subset">,files,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files-text']" />
    <xsl:with-param name="attr_name">changed</xsl:with-param>
    <xsl:with-param name="text2">
      <xsl:call-template name="output-granularity-type">
        <xsl:with-param name="text">files-text</xsl:with-param>
      </xsl:call-template>
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files-text,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files-image']" />
    <xsl:with-param name="attr_name">changed</xsl:with-param>
    <xsl:with-param name="text2">
      <xsl:call-template name="output-granularity-type">
        <xsl:with-param name="text">files-image</xsl:with-param>
      </xsl:call-template>
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files-image,</xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="statistics_data_line_per_diff_type">
    <xsl:with-param name="nodes" select="pair/granularity[@type='files-binary']" />
    <xsl:with-param name="attr_name">changed</xsl:with-param>
    <xsl:with-param name="text2">
      <xsl:call-template name="output-granularity-type">
        <xsl:with-param name="text">files-binary</xsl:with-param>
      </xsl:call-template>
    </xsl:with-param>
    <xsl:with-param name="types_subset">,files-binary,</xsl:with-param>
  </xsl:call-template>
  <xsl:value-of select="$kg_linefeed" />
  <xsl:text>*: </xsl:text><xsl:value-of select="$kg_all_files_explanation" />
  <xsl:if test="granularity[@type='files']/@conflicting &gt; 0">
    <xsl:value-of select="$kg_linefeed" />
    <xsl:call-template name="kg_merge_folders_with_conflicts">
      <xsl:with-param name="nb" select="granularity[@type='files']/@conflicting" />
    </xsl:call-template>
  </xsl:if>
  <xsl:value-of select="$kg_linefeed" />
</xsl:template>

<xsl:template name="statistics_data_line_per_diff_type">
<xsl:param name="nodes" />
<xsl:param name="attr_name" />
<xsl:param name="rowspan" />
<xsl:param name="colspan" />
<xsl:param name="text1" />
<xsl:param name="text2" />
<xsl:param name="types_subset" />
<xsl:param name="empty_col_before_01" select="'yes'" />

  <xsl:value-of select="$kg_linefeed" />
  <xsl:if test="string-length($text1) &gt; 0">
		<xsl:value-of select="$text1" />
    <xsl:if test="$rowspan > 1">
        <xsl:value-of select="$kg_linefeed" />
    </xsl:if>
	</xsl:if>
	<xsl:if test="string-length($text2) &gt; 0">
		<xsl:value-of select="$text2" />
    <xsl:text>&#9;</xsl:text>
	</xsl:if>
        
	<xsl:call-template name="statistics_data_per_type">
		<xsl:with-param name="nodes" select="$nodes" />
		<xsl:with-param name="attr_name" select="$attr_name" />
		<xsl:with-param name="types_subset" select="$types_subset" />
		<xsl:with-param name="empty_col_before_01" select="$empty_col_before_01" />
	</xsl:call-template>
</xsl:template>

<xsl:template name="statistics_data_per_type">
<xsl:param name="nodes" />
<xsl:param name="attr_name" />
<xsl:param name="types_subset" /> <!-- formatted as ",a,b,c," -->
<xsl:param name="empty_col_before_01" select="'yes'" />

	<xsl:for-each select="$nodes">
		<xsl:sort select="substring-before(../@roles, ',')" order="descending" />
		<xsl:sort select="substring-after(../@roles, ',')" order="ascending" />
		
		<xsl:variable name="node_type"><xsl:value-of select="concat(',', concat(@type, ','))" /></xsl:variable>
		<xsl:text>&#9;</xsl:text>
		<xsl:variable name="attr_text">
			<xsl:call-template name="attribute_by_name">
				<xsl:with-param name="node" select="." />
				<xsl:with-param name="name" select="$attr_name" />
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
		<xsl:when test="string-length($attr_text) &gt; 0">
			<xsl:value-of select="$attr_text" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>&#160;</xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
</xsl:template>

<xsl:template name="statistics_table_header">
<xsl:param name="pair_nodes" />
<xsl:param name="stats_nodes_count" />
<xsl:param name="description_title" />
<xsl:param name="description_rowspan" />
<xsl:param name="empty_col_before_01" select="'yes'" />

	<xsl:value-of select="$description_title" />
  <xsl:text>&#32;</xsl:text>
		
	<xsl:for-each select="$pair_nodes">
		<xsl:sort select="substring-before(@roles, ',')" order="descending" />
		<xsl:sort select="substring-after(@roles, ',')" order="ascending" />

	  <xsl:variable name="one">
		  <xsl:call-template name="source_role">
			  <xsl:with-param name="source_idx"><xsl:value-of select="substring-before(@roles, ',')" /></xsl:with-param>
		  </xsl:call-template>
	  </xsl:variable>
	  <xsl:variable name="two">
		  <xsl:call-template name="source_role">
			  <xsl:with-param name="source_idx"><xsl:value-of select="substring-after(@roles, ',')" /></xsl:with-param>
		  </xsl:call-template>
	  </xsl:variable>
	  <xsl:call-template name="kg_statistics_pair_info">
		  <xsl:with-param name="one" select="$one" />
		  <xsl:with-param name="two" select="$two" />
	  </xsl:call-template>
    <xsl:text>&#32;</xsl:text>
	</xsl:for-each>
</xsl:template>

<xsl:template name="statistics_table_header_data_types">
<xsl:param name="empty_left_cell" />
<xsl:param name="empty_left_cell_colspan" />
<xsl:param name="stats_nodes" />
<xsl:param name="types_subset" /> <!-- formatted as ",a,b,c," -->
<xsl:param name="empty_col_before_01" select="'yes'" />

  <xsl:value-of select="$kg_linefeed" />
	<xsl:for-each select="$stats_nodes">
		<xsl:sort select="substring-before(../@roles, ',')" order="descending" />
		<xsl:sort select="substring-after(../@roles, ',')" order="ascending" />

    <xsl:variable name="node_type">
      <xsl:value-of select="concat(',', concat(@type, ','))" />
    </xsl:variable>
    <xsl:text>&#9;</xsl:text>
    <xsl:call-template name="output-granularity-type">
			<xsl:with-param name="text" select="@type" />
		</xsl:call-template>
	</xsl:for-each>
  
</xsl:template>

<xsl:template name="statistics_table_content">
<xsl:param name="stats_nodes" />

	<xsl:value-of select="$kg_unchanged_items" />
	<xsl:call-template name="statistics_data_per_type">
		<xsl:with-param name="nodes" select="$stats_nodes" />
		<xsl:with-param name="attr_name">unchanged</xsl:with-param>
	</xsl:call-template>
  <xsl:value-of select="$kg_inserted_items" />
	<xsl:call-template name="statistics_data_per_type">
		<xsl:with-param name="nodes" select="$stats_nodes" />
		<xsl:with-param name="attr_name">inserted</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$kg_deleted_items" />
	<xsl:call-template name="statistics_data_per_type">
		<xsl:with-param name="nodes" select="$stats_nodes" />
		<xsl:with-param name="attr_name">deleted</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$kg_changed_items" />
	<xsl:call-template name="statistics_data_per_type">
		<xsl:with-param name="nodes" select="$stats_nodes" />
		<xsl:with-param name="attr_name">changed</xsl:with-param>
	</xsl:call-template>
	<xsl:if test="$g_can_ignore and $stats_nodes/@type!='files'">
		<xsl:value-of select="$kg_ignored_items" />
		<xsl:call-template name="statistics_data_per_type">
			<xsl:with-param name="nodes" select="$stats_nodes" />
			<xsl:with-param name="attr_name">ignored</xsl:with-param>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="details">

	<xsl:call-template name="details-common" />
</xsl:template>

<xsl:template match="sub-reports">

	<xsl:for-each select="sub-report/comparison-export">
		<xsl:apply-templates select="." />
	</xsl:for-each>
</xsl:template>

<xsl:template name="output-legend">

<!--
	<xsl:value-of select="$kg_linefeed" />
	<xsl:call-template name="output-legend-title" />
-->
</xsl:template>

<xsl:template name="output-class-code">
<xsl:param name="class" />

	<xsl:call-template name="output-class-code-common">
		<xsl:with-param name="class" select="$class" />
	</xsl:call-template>
</xsl:template>

<xsl:template name="use_file_name_filters">
<xsl:variable name="exclude_list">

	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@exclude_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@exclude_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="include_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@include_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@include_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

	<xsl:if test="$exclude_list">
		<xsl:text>yes</xsl:text>
	</xsl:if>
	<xsl:if test="$include_list">
		<xsl:text>yes</xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template name="display_file_status_filters">
<xsl:variable name="ignore_missing" select="@ignore_missing_in_source='yes' or @ignore_missing_in_target='yes' or @ignore_missing_in_ancestor='yes' or @ignore_missing_in_result='yes'" />
<xsl:variable name="ignore_present" select="@ignore_present_in_source='yes' or @ignore_present_in_target='yes' or @ignore_present_in_ancestor='yes' or @ignore_present_in_result='yes'" />
<xsl:variable name="display" select="@display_identical='no' or @display_different='no' or @display_conflicts='no'" />
<xsl:variable name="ignore" select="@ignore_hidden='yes' or @hide_empty_identical_folders='yes'" />

	<xsl:choose>
	<xsl:when test="$ignore_missing or $ignore_present or $display or $ignore">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_status_title" /></th>
		</tr>
		<xsl:if test="@ignore_missing_in_source='yes' or @ignore_missing_in_target='yes' or @ignore_missing_in_ancestor='yes' or @ignore_missing_in_result='yes'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_missing" /></th>
				<td>
					<xsl:if test="@ignore_missing_in_source='yes'">
						<xsl:value-of select="$kg_folder_filters_in_source" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_missing_in_target='yes'">
						<xsl:value-of select="$kg_folder_filters_in_target" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_missing_in_ancestor='yes'">
						<xsl:value-of select="$kg_folder_filters_in_ancestor" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_missing_in_result='yes'">
						<xsl:value-of select="$kg_folder_filters_in_result" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="@ignore_present_in_source='yes' or @ignore_present_in_target='yes' or @ignore_present_in_ancestor='yes' or @ignore_present_in_result='yes'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_present" /></th>
				<td>
					<xsl:if test="@ignore_present_in_source='yes'">
						<xsl:value-of select="$kg_folder_filters_in_source" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_present_in_target='yes'">
						<xsl:value-of select="$kg_folder_filters_in_target" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_present_in_ancestor='yes'">
						<xsl:value-of select="$kg_folder_filters_in_ancestor" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@ignore_present_in_result='yes'">
						<xsl:value-of select="$kg_folder_filters_in_result" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="@display_identical='no' or @display_different='no' or @display_conflicts='no'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_compared" /></th>
				<td>
					<xsl:if test="@display_identical='no'">
						<xsl:value-of select="$kg_folder_filters_identical" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@display_different='no'">
						<xsl:value-of select="$kg_folder_filters_different" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
					<xsl:if test="@display_conflicts='no'">
						<xsl:value-of select="$kg_folder_filters_conflicting" />
            <xsl:value-of select="$kg_linefeed" /><br/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="@ignore_hidden='yes' or @hide_empty_identical_folders='yes'">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_hide_others" /></th>
				<td>
					<xsl:if test="@ignore_hidden='yes'">
						<xsl:value-of select="$kg_folder_filters_hide_system_hidden" /><xsl:value-of select="$kg_linefeed" />
					</xsl:if>
					<xsl:if test="@hide_empty_identical_folders='yes'">
						<xsl:value-of select="$kg_folder_filters_hide_empty_identical_folders" /><xsl:value-of select="$kg_linefeed" />
					</xsl:if>					
				</td>
			</tr>
		</xsl:if>
		</table>
        <xsl:value-of select="$kg_linefeed" /><br/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_status" />
        <xsl:value-of select="$kg_linefeed" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display_file_date_filters">

	<xsl:choose>
	<xsl:when test="@use_date_filter='yes'">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_filedate_title" /></th>
		</tr>
		<tr>
			<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_exclude_files_by_date_title" /></th>
			<td>
				<xsl:call-template name="kg_folder_filters_exclude_files_by_date">
					<xsl:with-param name="before" select="@date_filter_exclude_files_before" />
					<xsl:with-param name="nb_days" select="@days_number" />
					<xsl:with-param name="date" select="@day_cutoff" />
					<xsl:with-param name="use_date" select="@date_filter_use_calendar" />
				</xsl:call-template>
			</td>
		</tr>
		<xsl:if test="@date_filter_if_all_sources='yes'">
			<tr>
				<td colspan="2"><xsl:value-of select="$kg_folder_filters_exclude_files_if_everywhere" /></td>
			</tr>
		</xsl:if>
        </table>
        <xsl:value-of select="$kg_linefeed" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_filedate" />
        <xsl:value-of select="$kg_linefeed" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display_file_name_filters">
<xsl:variable name="exclude_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@exclude_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@exclude_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="include_list">
	<xsl:choose>
	<xsl:when test="$g_is_3way_comparison">
		<xsl:value-of select="three_way/@include_list" />
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="two_way/@include_list" />
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

	<xsl:choose>
	<xsl:when test="string-length($include_list) &gt; 0 or string-length($exclude_list) &gt; 0">
		<table class="tablebox" cellspacing="1">
		<tr>
			<th colspan="2" class="tablebox_header hth"><xsl:value-of select="$kg_folder_filters_filename_title" /></th>
		</tr>
		<xsl:if test="string-length($include_list) &gt; 0">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_filename_include" /></th>
				<td><xsl:value-of select="$include_list" /></td>
			</tr>
		</xsl:if>
		<xsl:if test="string-length($exclude_list) &gt; 0">
			<tr>
				<th class="tablebox_header vth"><xsl:value-of select="$kg_folder_filters_filename_exclude" /></th>
				<td><xsl:value-of select="$exclude_list" /></td>
			</tr>
		</xsl:if>
		</table>
        <xsl:value-of select="$kg_linefeed" /><br/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$kg_no_folder_filters_filename" />
        <xsl:value-of select="$kg_linefeed" /><br/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="display_heading">
<xsl:param name="text" />
	<xsl:value-of select="$text" /><xsl:value-of select="$kg_linefeed" />
</xsl:template>

</xsl:stylesheet>
